<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}
/*=========== Posts Widget start ============*/

class blog_widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'morat-blog';
  }
  public function get_title() {
    return esc_html__('mediquet Blog', 'blog_widget');
  }
  public function get_categories() {
    return ['basic'];
  }

  /*=========== Posts Widget Controls start ============*/
  protected function register_controls() {
  // Content Section
  $this->start_controls_section(
    'content_section',
    [
      'label' => 'Content',
      'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
    ]
  );
  // Blog Style
  $this->add_control(
    'blog_style',
    [
      'label' => esc_html__('Blog Style', 'mediquet'),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => '1',
      'options' => [
        '1'  => esc_html__('Blog Style 01', 'mediquet'),
        '2' => esc_html__('Blog Style 02', 'mediquet'),
        '3' => esc_html__('Blog Style 03', 'mediquet'),
        '4' => esc_html__('Blog Style 04', 'mediquet'),
        '5' => esc_html__('Blog Style 05', 'mediquet'),
        '6' => esc_html__('Blog Style 06', 'mediquet'),
      ],
    ]
  );
  // Blog Post count
  $this->add_control(
    'post_count',
    [
      'label' => 'Number of Post',
      'type' => \Elementor\Controls_Manager::NUMBER,
      'max' => 12,
      'default' => 3
    ]
  ); 
  // Blog Post Alignment
	$this->add_responsive_control(
		'align',
		[
			'label' => esc_html__( 'Alignment', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => [
				'left' => [
					'title' => esc_html__( 'Left', 'mediquet' ),
					'icon' => 'eicon-text-align-left',
				],
				'center' => [
					'title' => esc_html__( 'Center', 'mediquet' ),
					'icon' => 'eicon-text-align-center',
				],
				'right' => [
					'title' => esc_html__( 'Right', 'mediquet' ),
					'icon' => 'eicon-text-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'mediquet' ),
					'icon' => 'eicon-text-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body' => 'text-align: {{VALUE}};',
			],
		]
	);
  	/* column_style*/
    $this->add_responsive_control(
      'witr_column_grid',
      [
          'label' => esc_html__( 'Columns style', 'mediquet' ),
          'type' => \Elementor\Controls_Manager::SELECT,					
          'default' => '3',
          'options' => [
              '12' => esc_html__( '1', 'mediquet' ),
              '6' => esc_html__( '2', 'mediquet' ),
              '4' => esc_html__( '3', 'mediquet' ),
              '3' => esc_html__( '4', 'mediquet' ),
              '2' => esc_html__( '6', 'mediquet' ),
          ],
      ]
  );
	// Show SWITCHER Button
  $this->add_control(
    'show_text',
    [
      'label' => esc_html__( 'Show Content', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SWITCHER,
      'label_on' => esc_html__( 'Show', 'mediquet' ),
      'label_off' => esc_html__( 'Hide', 'mediquet' ),
      'return_value' => 'yes',
      'default' => 'yes',
    ]
  );	
  // Show SWITCHER Icon
  $this->add_control(
    'show_icon',
    [
      'label' => esc_html__( 'Show Icon', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SWITCHER,
      'label_on' => esc_html__( 'Show', 'mediquet' ),
      'label_off' => esc_html__( 'Hide', 'mediquet' ),
      'return_value' => 'yes',
      'default' => 'yes',
    ]
  );
  // Blog Post Icon
  $this->add_control(
    'service_icon',
    [
      'label' => esc_html__('Icon', 'mediquet'),
      'type' => \Elementor\Controls_Manager::ICONS,
      'default' => [
        'value' => 'fas fa-circle',
        'library' => 'fa-solid',
      ],
      'recommended' => [
        'fa-solid' => [
          'circle',
          'dot-circle',
          'square-full',
        ],
        'fa-regular' => [
          'circle',
          'dot-circle',
          'square-full',
        ],
      ],
      'condition' => [
      'show_icon' => 'yes',
    ],
    ]
  );
	// Show Images  SWITCHER
  $this->add_control(
    'show_img',
    [
      'label' => esc_html__( 'Show images', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SWITCHER,
      'label_on' => esc_html__( 'Show', 'mediquet' ),
      'label_off' => esc_html__( 'Hide', 'mediquet' ),
      'return_value' => 'yes',
      'default' => 'yes',
    ]
  );	
	// post icon Image
  $this->add_control(
    'date_image',
    [
      'label' => esc_html__('Choose Image', 'mediquet'),
      'type' => \Elementor\Controls_Manager::MEDIA,
      'default' => [
        'url' =>plugin_dir_url(__DIR__) . 'assets/images/placeholder.png',
      ],
  'condition' => [
      'show_img' => 'yes',
    ],
    ]
  );
	// Show Icon
  $this->add_control(
    'show_btn',
    [
      'label' => esc_html__( 'Show Button', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SWITCHER,
      'label_on' => esc_html__( 'Show', 'mediquet' ),
      'label_off' => esc_html__( 'Hide', 'mediquet' ),
      'return_value' => 'yes',
      'default' => 'yes',
    ]
  );	
    // Blog Post adc
    $this->add_control(
      'adc_blog',
      [
        'label' => esc_html__( 'Blog ASC/DSC style', 'mediquet' ),
        'type' => \Elementor\Controls_Manager::SELECT,
                  'separator' => 'before',					
        'options' => [
          'DESC'	=> esc_html__( 'Descending', 'mediquet' ),
          'ASC'	=> esc_html__( 'Ascending', 'mediquet' )
        ],
        'default' => 'DESC',
      ]
    );
  // Button Text
  $this->add_control(
    'blog_button',
    [
      'label' => 'Button Text',
      'type' => \Elementor\Controls_Manager::TEXT,
      'default' => 'Read More',
  'condition' => [
      'show_btn' => 'yes',
    ],
    ]
  );
  // Blog Button Url 
  $this->add_control(
    'button_link',
    [
      'label' => esc_html__('Button Link', 'mediquet'),
      'type' => \Elementor\Controls_Manager::URL,
      'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
      'options' => ['url', 'is_external', 'nofollow'],
      'default' => [
        'url' => '#',
      ],
      'label_block' => true,
    ],
  
  );
	// Post count
  $this->add_control(
    'content_show',
    [
      'label' => 'Content of Post',
      'type' => \Elementor\Controls_Manager::NUMBER,
      'max' => 150,
      'default' => 17,
    ]
  );
  $this->end_controls_section();

	/*===========Blog  Slick Option Start ============*/
  $this->start_controls_section(
    'slider_section',
    [
      'label' => 'Slick Option',
      'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
    ]
  );
	// Auto Play
  $this->add_control(
    'auto_play',
    [
      'label' => esc_html__('Auto Play', 'mediquet'),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => 'true',
      'options' => [
        'true'  => esc_html__('True', 'mediquet'),
        'false' => esc_html__('False', 'mediquet'),
      ],
    ]
  );
  // Speed
  $this->add_control(
    'speed',
    [
      'label' => esc_html__('Speed', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 100,
      'max' => 10000,
      'default' => 900,
    ]
  );
  // AutoPlay Speed
  $this->add_control(
    'autoplay_speed',
    [
      'label' => esc_html__('Autoplay Speed', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 100,
      'max' => 10000,
      'default' => 900,
    ]
  );
  // Slide To Show
  $this->add_control(
    'slide_to_show',
    [
      'label' => esc_html__('Slide To Show', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 1,
      'max' => 6,
      'default' => 3,
    ]
  ); 
  // Slide To Scroll
  $this->add_control(
    'slide_to_scroll',
    [
      'label' => esc_html__('Slide To Scroll', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 1,
      'max' => 6,
      'default' => 1,
    ]
  );
  // Slide Dot
  $this->add_control(
    'dot',
    [
      'label' => esc_html__('Dot', 'mediquet'),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => 'false',
      'options' => [
        'true'  => esc_html__('True', 'mediquet'),
        'false' => esc_html__('False', 'mediquet'),
      ],
    ]
  );
  // Posts Slider Arrows
  $this->add_control(
    'arrows',
    [
      'label' => esc_html__('Arrows', 'mediquet'),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => 'true',
      'options' => [
        'true'  => esc_html__('True', 'mediquet'),
        'false' => esc_html__('False', 'mediquet'),
      ],
    ]
  );
  // Posts Slider  Infinite
  $this->add_control(
    'infinite',
    [
      'label' => esc_html__('Infinite', 'mediquet'),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => 'true',
      'options' => [
        'true'  => esc_html__('True', 'mediquet'),
        'false' => esc_html__('False', 'mediquet'),
      ],
    ]
  );
  // Arrows
  $this->add_control(
    'slider_centermode',
    [
      'label' => esc_html__('centerMode', 'mediquet'),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => 'false',
      'options' => [
        'true'  => esc_html__('True', 'mediquet'),
        'false' => esc_html__('False', 'mediquet'),
      ],
    ]
  );
  // Slide To Show
  $this->add_control(
    'slide_rea_show',
    [
      'label' => esc_html__('Mobel Show', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 1,
      'max' => 6,
      'default' => 2,
    ]
  );
	//  Posts Slider To Show
  $this->add_control(
    'slide_reas_show',
    [
      'label' => esc_html__('Tablet Show', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 1,
      'max' => 6,
      'default' => 2,
    ]
  );
	// Slide To Show
  $this->add_control(
    'slide_reass_show',
    [
      'label' => esc_html__('Desktop Show', 'mediquet'),
      'type' => \Elementor\Controls_Manager::NUMBER,
      'min' => 1,
      'max' => 6,
      'default' => 2,
    ]
  );
	
  $this->end_controls_section();

  /*=========== Posts Widget Box Style start ============*/
  $this->start_controls_section(
    'blog_box_style',
    [
      'label' => 'Box Color Option',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
	// Box Background  
  $this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
      'name' => 'blog_background',
      'label' => esc_html__('Background', 'mediquet'),
      'types' => ['classic', 'gradient'],
      'selector' => '{{WRAPPER}} .txt_blog_body ',
    ]
  ); 
  // Posts Box Padding 
  $this->add_responsive_control(
    'ser_box_padding',
    [
      'label' => 'Padding',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .txt_blog_body ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );
  // Posts Box Margin
  $this->add_responsive_control(
    'ser_box_margin',
    [
      'label' => 'Margin',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .txt_blog_body ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );
	//  Posts box shadow 
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'witr_box_shadowsbox',
			'label' => esc_html__( 'Box Shadow', 'mediquet' ),
			'selector' => '{{WRAPPER}} .txt_blog_body ',
		]
	); 
	//  Posts Border Style 
	$this->add_control(
		'box_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .txt_blog_body ' => 'border-style: {{VALUE}}',
			],
		]
	);		
	// Posts border  Width
	$this->add_control(
		'box_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .txt_blog_body ' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'boxs_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body ' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'service_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .txt_blog_body ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	/* border_color */
	$this->add_control(
		'border1_hover_color',
		[
			'label' => esc_html__( 'Border Hover Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_blog_all_area:hover .txt_blog_body, {{WRAPPER}} .slick-center .txt_blog_body' => 'border-color: {{VALUE}}',
			],
		]
	);
	
	$this->end_controls_section();

	/*=========== Blog posts  Title Styler start ============*/
  $this->start_controls_section(
    'title_style',
    [
      'label' => 'Main Title',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
  // post Title Color
  $this->add_control(
    'post_heading_color',
    [
      'label' => esc_html__('Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .post_widget_title a' => 'color: {{VALUE}} !important',
      ],
    ]
  );
  // post Title Typography
  $this->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
      'name' => 'post_title_typography',
      'selector' => '{{WRAPPER}} .post_widget_title a',
    ]
  );
  // post Title Padding
  $this->add_responsive_control(
    'title_padding',
    [
      'label' => 'Padding',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .post_widget_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );
  // post Title Margin
  $this->add_responsive_control(
    'post_title_margin',
    [
      'label' => 'Margin',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .post_widget_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );
  $this->end_controls_section();
	
	/*=========== Blog posts  Content Styler start ============*/
	$this->start_controls_section(
    'content_style',
    [
      'label' => 'Content Title',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
  // posts Content Color
  $this->add_control(
    'content_color',
    [
      'label' => esc_html__('Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .txt_blog_body p' => 'color: {{VALUE}} !important',
      ],
    ]
  );
  // posts Content  Typography
  $this->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
      'name' => 'content_typography',
      'selector' => '{{WRAPPER}} .txt_blog_body p',
    ]
  );

  //posts  Content Margin
  $this->add_responsive_control(
    'content_margin',
    [
      'label' => 'Margin',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .txt_blog_body p' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );

  $this->end_controls_section();
	
	/*=========== Blog posts  Meta Styler start ============*/
  $this->start_controls_section(
    'meta_style',
    [
      'label' => 'Meta',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
  // Posts Meta Color
  $this->add_control(
    'meta_color',
    [
      'label' => esc_html__('Meta Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .date_all span' => 'color: {{VALUE}}',
      ],
    ]
  );
 // Posts Meta Background
  $this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
      'name' => 'meta_bg',
      'label' => esc_html__('Meta Background', 'mediquet'),
      'types' => ['classic', 'gradient'],
      'selector' => '{{WRAPPER}} .date_all',
    ]
  );
  // Posts Meta Meta Typography
  $this->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
      'name' => 'meta_typography',
      'selector' => '{{WRAPPER}} .date_all span',
    ]
  );

   //  Posts box shadow 
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'meta_box_shadowsbox',
			'label' => esc_html__( 'Box Shadow', 'mediquet' ),
			'selector' => '{{WRAPPER}} .date_all ',
		]
	); 
  /*Position */
  $this->add_responsive_control(
    'category_position',
    [
      'label' => esc_html__( 'Position', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'default' => '',
      'options' => [
        '' => esc_html__( 'Default', 'mediquet' ),
        'absolute' => esc_html__( 'Absolute', 'mediquet' ),
        'fixed' => esc_html__( 'Fixed', 'mediquet' ),
        'inherit' => esc_html__( 'inherit', 'mediquet' ),
      ],
      'selectors' => [
            '{{WRAPPER}} .date_all' => 'position: {{VALUE}};',
          ],
    ]
  );

// category Top
$this->add_responsive_control(
  'category_top',
  [
    'label' => esc_html__( 'category Top', 'elementor' ),
    'type' => \Elementor\Controls_Manager::SLIDER,
    'size_units' => [ 'px', '%' ],
    'range' => [
      'px' => [
        'min' => -1000,
        'max' => 500,
      ],
      '%' => [
        'min' => -1000,
        'max' => 100,
      ],		
    ],						
    'selectors' => [
      '{{WRAPPER}} .date_all' => 'top: {{SIZE}}{{UNIT}};',
    ],
  ]
);	
// images Left
$this->add_responsive_control(
  'category_Left',
    [
      'label' => esc_html__( 'category Left', 'elementor' ),
      'type' => \Elementor\Controls_Manager::SLIDER,
      'size_units' => [ 'px', '%' ],
      'range' => [
        'px' => [
          'min' => -1000,
          'max' => 500,
        ],
        '%' => [
          'min' => -1000,
          'max' => 100,
        ],		
      ],						
      'selectors' => [
        '{{WRAPPER}} .date_all' => 'left: {{SIZE}}{{UNIT}};',
      ],
    ]
  );
	/* border_radius */
	$this->add_control(
		'category_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .date_all' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],								
		]
  );


  $this->end_controls_section();

  /*=========== Blog posts  Exerpt Styler start ============*/
  $this->start_controls_section(
    'date_style',
    [
      'label' => 'Date Style',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
  // Posts Meta Color
  $this->add_control(
    'date_color',
    [
      'label' => esc_html__('Date Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .date_time span, {{WRAPPER}} .txt_blog_inner span' => 'color: {{VALUE}}',
      ],
    ]
  );
  // Meta Typogrphy
  $this->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
      'name' => 'date_typography',
      'selector' => '{{WRAPPER}} .date_time span, {{WRAPPER}} .txt_blog_inner span',
    ]
  );
  //  Meta Color
  $this->add_control(
    'date-icon_color',
    [
      'label' => esc_html__('Date Icon Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .date_all span i' => 'color: {{VALUE}}',
      ],
    ]
  );


  $this->end_controls_section();

	/*=========== Blog posts  Button Style Section start ============*/
  $this->start_controls_section(
    'button_style',
    [
      'label' => 'Button Color Option',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
  // posts Button tab
  $this->start_controls_tabs(
    'posts_button_style_tabs'
  );
  // posts Button Normal Tab
  $this->start_controls_tab(
    'post_normal_tab',
    [
      'label' => esc_html__('Normal', 'mediquet'),
    ]
  );
  // posts Button Typography
  $this->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
      'name' => 'button_typography',
      'selector' => '{{WRAPPER}} .stxt_btn .tabtn',
    ]
  );
  // posts Button Color
  $this->add_control(
    'post_title_color',
    [
      'label' => esc_html__('Title Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} a.tabtn , {{WRAPPER}} a.tabtn i' => 'color: {{VALUE}}',
      ],
    ]
  );
  // posts Button Background
  $this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
      'name' => 'background',
      'label' => esc_html__('Background', 'mediquet'),
      'types' => ['classic', 'gradient'],
      'selector' => '{{WRAPPER}} a.tabtn',
    ]
  );
 // posts Button padding
  $this->add_responsive_control(
      'button_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} a.tabtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	/* posts Button border radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	// posts Button Box Margin
  $this->add_responsive_control(
    'button_margin',
    [
      'label' => 'Margin',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .stxt_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      
    ]
  );
  // Arrow Width
  $this->add_responsive_control(
    'button_width',
    [
      'type' => \Elementor\Controls_Manager::SLIDER,
      'label' => esc_html__('Width', 'mediquet'),
      'size_units' => ['px', '%'],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 500,
        ],
        '%' => [
          'min' => 0,
          'max' => 100
        ]
      ],
      'selectors' => [
        '{{WRAPPER}} .stxt_btn a.tabtn' => 'width: {{SIZE}}{{UNIT}};',
      ],
    ]
  );
  // Arrow height
  $this->add_responsive_control(
    'button__height',
    [
      'type' => \Elementor\Controls_Manager::SLIDER,
      'label' => esc_html__('height', 'mediquet'),
      'size_units' => ['px', '%'],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 500,
        ],
        '%' => [
          'min' => 0,
          'max' => 100
        ]
      ],
      'selectors' => [
        '{{WRAPPER}} .stxt_btn a.tabtn' => 'height: {{SIZE}}{{UNIT}};',
      ],
    ]
  );	
  // Arrow height
  $this->add_responsive_control(
    'button__line_height',
    [
      'type' => \Elementor\Controls_Manager::SLIDER,
      'label' => esc_html__('line-height', 'mediquet'),
      'size_units' => ['px', '%'],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 500,
        ],
        '%' => [
          'min' => 0,
          'max' => 100
        ]
      ],
      'selectors' => [
        '{{WRAPPER}} .stxt_btn a.tabtn' => 'line-height: {{SIZE}}{{UNIT}};',
      ],
    ]
  );




  $this->end_controls_tab();

  // posts Button Hover Tab
  $this->start_controls_tab(
    'style_hover_tab',
    [
      'label' => esc_html__('Hover', 'mediquet'),
    ]
  );
  // posts Button Hover Color
  $this->add_control(
    'hover_title_color',
    [
      'label' => esc_html__('Title Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} a.tabtn:hover' => 'color: {{VALUE}}',
      ],
    ]
  );
  //posts Button Hover Background
  $this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
      'name' => 'hover_background',
      'label' => esc_html__('Background', 'mediquet'),
      'types' => ['classic', 'gradient'],
      'selector' => '{{WRAPPER}} a.tabtn:hover',
    ]
  );

  $this->end_controls_tab();
  

  // posts Button Hover Tab
  $this->start_controls_tab(
    'style_arrow_tab',
    [
      'label' => esc_html__('arrow', 'mediquet'),
    ]
  );
 // posts Button Typography
 $this->add_group_control(
  \Elementor\Group_Control_Typography::get_type(),
  [
    'name' => 'button_arrows_typography',
    'selector' => '{{WRAPPER}} .stxt_btn a i',
  ]
);
// posts Button Color
$this->add_control(
  'button_arrow_color',
  [
    'label' => esc_html__('Title Color', 'mediquet'),
    'type' => \Elementor\Controls_Manager::COLOR,
    'selectors' => [
      '{{WRAPPER}} .stxt_btn a i' => 'color: {{VALUE}}',
    ],
  ]
);
// posts Button Background
$this->add_group_control(
  \Elementor\Group_Control_Background::get_type(),
  [
    'name' => 'arrow_background',
    'label' => esc_html__('Background', 'mediquet'),
    'types' => ['classic', 'gradient'],
    'selector' => '{{WRAPPER}} .stxt_btn a i',
  ]
);
// posts Button padding
$this->add_responsive_control(
    'button_arrow_padding',
    [
      'label' => 'Padding',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .stxt_btn a i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );
/* posts Button border radius */
$this->add_control(
  'btn_arrow_radius',
  [
    'label' => esc_html__( 'Border Radius', 'mediquet' ),
    'type' => \Elementor\Controls_Manager::DIMENSIONS,
    'size_units' => [ 'px', '%' ],
    'selectors' => [
      '{{WRAPPER}} .stxt_btn a i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    ],							
  ]
);
// posts Button Box Margin
$this->add_responsive_control(
  'button_arrow_margin',
  [
    'label' => 'Margin',
    'type' => \Elementor\Controls_Manager::DIMENSIONS,
    'size_units' => ['px', 'em', '%'],
    'selectors' => [
      '{{WRAPPER}} .stxt_btn a i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    ],
    
  ]
);
// Arrow Width
$this->add_responsive_control(
  'button_arrows_width',
  [
    'type' => \Elementor\Controls_Manager::SLIDER,
    'label' => esc_html__('Width', 'mediquet'),
    'size_units' => ['px', '%'],
    'range' => [
      'px' => [
        'min' => 0,
        'max' => 500,
      ],
      '%' => [
        'min' => 0,
        'max' => 100
      ]
    ],
    'selectors' => [
      '{{WRAPPER}} .stxt_btn a i' => 'width: {{SIZE}}{{UNIT}};',
    ],
  ]
);
// Arrow height
$this->add_responsive_control(
  'button_arrows_height',
  [
    'type' => \Elementor\Controls_Manager::SLIDER,
    'label' => esc_html__('height', 'mediquet'),
    'size_units' => ['px', '%'],
    'range' => [
      'px' => [
        'min' => 0,
        'max' => 500,
      ],
      '%' => [
        'min' => 0,
        'max' => 100
      ]
    ],
    'selectors' => [
      '{{WRAPPER}} .stxt_btn a i' => 'height: {{SIZE}}{{UNIT}};',
    ],
  ]
);	
// Arrow height
$this->add_responsive_control(
  'button_arrow_height',
  [
    'type' => \Elementor\Controls_Manager::SLIDER,
    'label' => esc_html__('line-height', 'mediquet'),
    'size_units' => ['px', '%'],
    'range' => [
      'px' => [
        'min' => 0,
        'max' => 500,
      ],
      '%' => [
        'min' => 0,
        'max' => 100
      ]
    ],
    'selectors' => [
      '{{WRAPPER}} .stxt_btn a i' => 'line-height: {{SIZE}}{{UNIT}};',
    ],
  ]
);





  $this->end_controls_tab();
  $this->end_controls_tabs();

	
	$this->end_controls_section();
  /*=========== Posts Widget Box Style start ============*/
  $this->start_controls_section(
    'blog_img_style',
    [
      'label' => 'Blog Images Option',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
   // images Width
   $this->add_responsive_control(
		'blog_image_width',
		[
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__( 'Width', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				]
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
			'selectors' => [
				'{{WRAPPER}} .txt_blg_image img' => 'width: {{SIZE}}{{UNIT}};',
			],
		]
	);

    // images Height
    $this->add_responsive_control(
		'blog_image_height',
		[
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__( 'Height', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				]
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
			'selectors' => [
				'{{WRAPPER}} .txt_blg_image img' => 'height: {{SIZE}}{{UNIT}};',
			],
		]
	);

	// images max width	
	$this->add_responsive_control(
		'blog_image_max_width',
		[
			'label' => esc_html__( 'Max Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'default' => [
				'unit' => '%',
			],
			'tablet_default' => [
				'unit' => '%',
			],
			'mobile_default' => [
				'unit' => '%',
			],
			'size_units' => [ '%', 'px', 'vw' ],
			'range' => [
				'%' => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1000,
				],
				'vw' => [
					'min' => 1,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .txt_blg_image img' => 'max-width: {{SIZE}}{{UNIT}};',
			],
		]
	);
  // Posts Box Padding 
  $this->add_responsive_control(
    'blog_image_padding',
    [
      'label' => 'Padding',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .txt_blg_image ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );
  // Posts Box Margin
  $this->add_responsive_control(
    'blog_image_margin',
    [
      'label' => 'Margin',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .txt_blg_image ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );

	//  Posts Border Style 
	$this->add_control(
		'blog_img_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .txt_blg_image ' => 'border-style: {{VALUE}}',
			],
		]
	);		
	// Posts border  Width
	$this->add_control(
		'img_border_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .txt_blg_image ' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'blog_img_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'img_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_blg_image ' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'blog_img_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'blog_image_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .txt_blg_image ' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	$this->end_controls_section();
	
	
	
  }

  
  /*=========== Blog Posts protected render start ============*/ 
  protected function render() {
    $settings = $this->get_settings_for_display();

    // Query Posts
    $args = array(
      'post_type' => 'post',
      'post_status' => 'publish',
      'posts_per_page' => $settings['post_count'],
      'orderby' => 'title',
      'order' => $settings['adc_blog'],
    );
    
    $loop = new WP_Query($args);
    ?>
    <div class="row">
      <?php while ($loop->have_posts()) : $loop->the_post(); ?>
      <?php if ($settings['blog_style'] == '1') : ?>
      <!--========  blog posts style 01 ======== -->
      <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item">
        <div class="txt_blog_all_area">
          <div class="txt_blg_image">
            <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
          </div>
          <div class="txt_blog_body">
            <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
            <?php if('yes' === $settings['show_text']): ?>
            <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_content(),  $settings['content_show'], '' ); ?></p>
            <?php endif ?>
            <div class="date_all thumb_area">
              <span>
                <?php if('yes' === $settings['show_img']): ?>
                <img src="<?= esc_url($settings['date_image']['url']) ?>" alt="">
                <?php endif ?>Mira
              </span>
              <span><?= the_modified_date() ?></span>
            </div>
            <div class="stxt_btn">
              <?php if('yes' === $settings['show_btn']): ?>
                <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['blog_button'] ?></a>
              <?php endif ?>
              </div>
          </div>
        </div>
      </div>
      <?php else : ?>
      <?php if ($settings['blog_style'] == '2') : ?>
        <!--========  blog posts style 02 ======== -->
        <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item">
          <div class="txt_blog_all_area style_02">
            <div class="txt_blg_image">
              <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
            </div>
            <div class="bl_ic">
              <?php if('yes' === $settings['show_icon']): ?>
              <?php \Elementor\Icons_Manager::render_icon($settings['service_icon'], ['aria-hidden' => 'true', 'class' => 'service_icon']); ?>
              <?php endif ?>
            </div>
            <div class="txt_blog_body">
              <div class="txt_blog_inner">
                <div class="date_all">
                  <span><?= get_the_category()[0]->cat_name ?></span>
                </div>
                <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
                <?php if('yes' === $settings['show_text']): ?>
                <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_content(),  $settings['content_show'], '' ); ?></p>
                <?php endif ?>
                <div class="date_time">
                 <span><?= the_modified_date() ?></span>
                </div>
              </div>
              <div class="stxt_btn">
                <?php if('yes' === $settings['show_btn']): ?>
                  <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['blog_button'] ?></a>
                <?php endif ?>
                </div>
            </div>
          </div>
        </div>
        <?php else : ?>
        <?php if ($settings['blog_style'] == '3') : ?>
          <!--========  blog posts style 03 ======== -->
          <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item">
            <div class="txt_blog_all_area style_03">
               <div class="date_time">
                 <span><?= the_modified_date() ?></span>
                </div>
              <div class="txt_blg_image">
                <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
                <div class="txt_blog_inner">
                  <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
                  <?php if('yes' === $settings['show_text']): ?>
                  <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_content(),  $settings['content_show'], '' ); ?></p>
                <?php endif ?>
                </div>
                </div>
                <div class="content_option">
                <div class="admin_option">
                <span> By: Admin</span>
                </div>
                <div class="stxt_btn">
                <?php if('yes' === $settings['show_btn']): ?>
                  <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['blog_button'] ?></a>
                <?php endif ?>
                </div>
              </div>
            </div>
            </div>
          <?php else : ?>
          <?php if ($settings['blog_style'] == '4') : ?>
            <!--========  blog posts style 04 ======== -->
            <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item">
              <div class="txt_blog_all_area style_02 style_04">
                <div class="txt_blg_image">
                  <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
                </div>
                <div class="txt_blog_body">
                  <div class="txt_blog_inner">
                    <span> By:<?= the_category() ?> </span> 
                    <span><i class="icofont-calendar"></i> <?= the_modified_date() ?></span>
                    <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
                    <?php if('yes' === $settings['show_text']): ?>
                      <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_content(),  $settings['content_show'], '' ); ?></p>
                    <?php endif ?>
                  </div>
                  <div class="stxt_btn">
                  <?php if('yes' === $settings['show_btn']): ?>
                    <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['blog_button'] ?></a>
                  <?php endif ?>
                  </div>
                </div>
              </div>
            </div>
            
            <?php else : ?>
          <?php if ($settings['blog_style'] == '5') : ?>
            <!--========  blog posts style 04 ======== -->
            <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item">
            <div class="txt_blog_all_area style_02 style_05">
                <div class="txt_blg_image">
                  <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
                </div>
                <div class="txt_blog_body">
                  <div class="txt_blog_inner">
                      <div class="date_all">
                      <span><i class="icofont-user-male"></i> <?= get_the_category()[0]->cat_name ?></span>
                      <span><i class="icofont-calendar"></i> <?= the_modified_date() ?></span>
                    </div>
                    <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
                    <?php if('yes' === $settings['show_text']): ?>
                      <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_content(),  $settings['content_show'], '' ); ?></p>
                    <?php endif ?>
                  </div>
                  
                  <div class="stxt_btn">
                  <?php if('yes' === $settings['show_btn']): ?>
                    <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['blog_button'] ?></a>
                  <?php endif ?>
                  </div>
                </div>
              </div>
            </div>
            <?php else : ?>
          <?php if ($settings['blog_style'] == '6') : ?>
            <!--========  blog posts style 04 ======== -->
            <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item">
              <div class="txt_blog_all_area style_02 style_05">
                <div class="txt_blg_image">
                  <a href="#"> <img src="<?= the_post_thumbnail_url() ?>" alt=""> </a>
                </div>
                <div class="txt_blog_body">
                  <div class="txt_blog_inner">
                    <h3 class="post_widget_title"><a href="<?= get_post_permalink() ?>"><?= the_title(); ?></a></h3>
                    <?php if('yes' === $settings['show_text']): ?>
                      <p class="post_widget_exerpt"><?php echo wp_trim_words( get_the_content(),  $settings['content_show'], '' ); ?></p>
                    <?php endif ?>
                    <div class="stxt_btn">
                    <?php if('yes' === $settings['show_btn']): ?>
                      <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['blog_button'] ?></a>
                    <?php endif ?>
                  </div>
                  <div class="date_time">
                    <span> <i class="icofont-calendar"></i> <?= the_modified_date() ?></span>
                    <a href="<?php comments_link(); ?>"><i class="icofont-comment"></i>
																<?php comments_number( esc_html__('0','mediquet'), esc_html__('1 ','mediquet'), esc_html__('% ','mediquet') );?>
															</a>	
                  </div>
                  </div>
                </div>
              </div>
            </div>
            <?php endif ?>
            <?php endif ?>
            <?php endif ?>
            <?php endif ?>
            <?php endif ?>
            <?php endif ?>

            <?php endwhile;
              wp_reset_postdata();
             ?>
    
    </div>

	 <?php if (is_admin()) :
      if (!defined('ELEMENTOR_VERSION'))
        return;
    ?>

    <?php endif ?>
	


<?php
  }
}
