<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Button Widget
 */

class Button_Widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'morat-button';
  }

  public function get_title()
  {
    return esc_html__('mediquet Button', 'mediquet-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }


  protected function register_controls()
  {
    /**
     * Button Control Section
     */
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
	
	$this->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tbd_ab_btn' => 'text-align: {{VALUE}};',
				],
			]
		);
	
	$this->add_control(
      'btn_txt',
      [
        'label' => ' Button Text',
        'type' => \Elementor\Controls_Manager::TEXT,
        'placeholder' => 'MType button text ',
        'default' => 'Read More'
      ]
    );

    // Url
    $this->add_control(
      'button_link',
      [
        'label' => esc_html__('Link', 'mediquet'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '#',
        ],
        'label_block' => true,
      ]
    );

    $this->end_controls_section();

    /**
     * Button Style Section
     */
    $this->start_controls_section(
      'button_style',
      [
        'label' => 'Button Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->start_controls_tabs(
      'button_style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'style_button_tab',
      [
        'label' => esc_html__('Normal', 'mediquet'),
      ]
    );

	// Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );
	
    // Color
    $this->add_control(
      'app_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );

	 /* witr_border_style */
	$this->add_control(
		'btn_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} a.tabtn' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'btn_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} a.tabtn' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'btn_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'btn_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'btn_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	
	/* border_radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
		  // Padding
      $this->add_responsive_control(
        'button_padding',
        [
          'type' => \Elementor\Controls_Manager::DIMENSIONS,
          'label' => esc_html__( 'Padding', 'mediquet' ),
          'size_units' => [ 'px', 'em', '%' ],
          'selectors' => [
            '{{WRAPPER}} .tabtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          ],
        ]
      );
  
  // Box Margin
      $this->add_responsive_control(
        'ser_box_margin',
        [
          'label' => 'Margin',
          'type' => \Elementor\Controls_Manager::DIMENSIONS,
          'size_units' => ['px', 'em', '%'],
          'selectors' => [
            '{{WRAPPER}} .tbd_ab_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
          ],
          'separator' => 'before',
        ]
      );
  
    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'style_hover_tab',
      [
        'label' => esc_html__('Hover', 'mediquet'),
      ]
    );

    // Color
    $this->add_control(
      'button_hover_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn:hover' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'hover_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tabtn:hover',
      ]
    );
	
	
	
	/* border_color */
	$this->add_control(
		'before2_color',
		[
			'label' => esc_html__( 'Border Hover Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} a.tabtn:hover.tabtn:after' => 'border-color: {{VALUE}}',
			],								
		]
	);

    $this->end_controls_tab();

   // Hover Tab
   $this->start_controls_tab(
    'style_Btn_icon_tab',
    [
      'label' => esc_html__('Btn Icon', 'mediquet'),
    ]
  );
// Typography
$this->add_group_control(
  \Elementor\Group_Control_Typography::get_type(),
  [
    'name' => 'button_icon_typography',
    'selector' => '{{WRAPPER}} a.tabtn i',
  ]
);

// Color
$this->add_control(
  'btn_icon_color',
  [
    'label' => esc_html__('Icon Color', 'mediquet'),
    'type' => \Elementor\Controls_Manager::COLOR,
    'selectors' => [
      '{{WRAPPER}} a.tabtn i' => 'color: {{VALUE}}',
    ],
  ]
);


// Background
$this->add_group_control(
  \Elementor\Group_Control_Background::get_type(),
  [
    'name' => 'btn_icon_background',
    'label' => esc_html__('Background', 'mediquet'),
    'types' => ['classic', 'gradient'],
    'selector' => '{{WRAPPER}} a.tabtn i',
  ]
);

/* witr_border_style */
$this->add_control(
'btn_icon_border',
[
  'label' => esc_html__( 'Border Style', 'mediquet' ),
  'type' => \Elementor\Controls_Manager::SELECT,
  'options' => [
    'none' => esc_html__( 'none', 'mediquet' ),
    'solid' => esc_html__( 'Solid', 'mediquet' ),
    'double' => esc_html__( 'Double', 'mediquet' ),
    'dotted' => esc_html__( 'Dotted', 'mediquet' ),
    'dashed' => esc_html__( 'Dashed', 'mediquet' ),
    'default' => esc_html__( 'Default', 'mediquet' ),
  ],
  'default' => 'none',
  'selectors' => [
     '{{WRAPPER}} a.tabtn i' => 'border-style: {{VALUE}}',
  ],
]
);		
/* witr border */

$this->add_control(
'btn_icon_bods_style',
[
  'label' => esc_html__( 'Width', 'mediquet' ),
  'type' => \Elementor\Controls_Manager::DIMENSIONS,
  'selectors' => [
     '{{WRAPPER}} a.tabtn i' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
  ],
  'condition' => [
    'btn_icon_border' => ['solid','double','dotted','dashed'],
  ],								
]
);
/* border_color */
$this->add_control(
'btn_icon_border1_color',
[
  'label' => esc_html__( 'Border Color', 'mediquet' ),
  'type' =>  \Elementor\Controls_Manager::COLOR,
  
  'selectors' => [
    '{{WRAPPER}} a.tabtn i' => 'border-color: {{VALUE}}',
  ],
  'condition' => [
    'btn_icon_border' => ['solid','double','dotted','dashed','default'],
  ],								
]
);

/* border_radius */
$this->add_control(
'btn_icon_radius',
[
  'label' => esc_html__( 'Border Radius', 'mediquet' ),
  'type' => \Elementor\Controls_Manager::DIMENSIONS,
  'size_units' => [ 'px', '%' ],
  'selectors' => [
    '{{WRAPPER}} a.tabtn i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
  ],							
]
);


  // Padding
  $this->add_responsive_control(
    'button_icon_padding',
    [
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'label' => esc_html__( 'Padding', 'mediquet' ),
      'size_units' => [ 'px', 'em', '%' ],
      'selectors' => [
        '{{WRAPPER}} a.tabtn i' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
    ]
  );

// Box Margin
  $this->add_responsive_control(
    'button_icon_margin',
    [
      'label' => 'Margin',
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} a.tabtn i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'separator' => 'before',
    ]
  );


  $this->end_controls_tab();



    $this->end_controls_tabs();


  
	 
	
	
	
    $this->end_controls_section();
  }


  protected function render()
  {
    $settings = $this->get_settings_for_display();
    if (!empty($settings['button_link']['url'])) {
      $this->add_link_attributes('button_link', $settings['button_link']);
    }
?>

    <div class="tbd_ab_btn">
	  <a <?php echo $this->get_render_attribute_string('button_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
    </div>

<?php
  }
}
