<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Counter Widget
 */

class Contact_Form_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'morat-contact-form';
  }

  public function get_title() {
    return esc_html__('Contact From', 'mediquet-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $this->add_control(
      'contact_form_list',
      [
        'label' => esc_html__('Select Form', 'essential-addons-for-elementor-lite'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'label_block' => true,
        'options' => mediquet_get_wpcf7_list(),
        'default' => '0',
      ]
    );

    $this->add_control(
      'mail_to',
      [
        'label' => 'Mail to',
        'type' => \Elementor\Controls_Manager::TEXT
      ]
    );

    $this->add_control(
      'button_text',
      [
        'label' => 'Button Text',
        'type' => \Elementor\Controls_Manager::TEXT
      ]
    );

    $this->end_controls_section();
	
	
	// contact_box_style
	
	$this->start_controls_section(
      'contact_box_style',
      [
        'label' => 'contact box',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
	
	/* witr_border_style */
		$this->add_control(
			'contact_border',
			[
				'label' => esc_html__( 'contact Border Style', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'none', 'mediquet' ),
					'solid' => esc_html__( 'Solid', 'mediquet' ),
					'double' => esc_html__( 'Double', 'mediquet' ),
					'dotted' => esc_html__( 'Dotted', 'mediquet' ),
					'dashed' => esc_html__( 'Dashed', 'mediquet' ),
					'default' => esc_html__( 'Default', 'mediquet' ),
				],
				'default' => 'default',
				'selectors' => [
					'{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area' => 'border-style: {{VALUE}}',
				],
			]
		);		
		/* witr border */
		
		$this->add_control(
			'contact_style',
			[
				'label' => esc_html__( 'Width', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'selectors' => [
					'{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'contact_border' => ['solid','double','dotted','dashed'],
				],								
			]
		);
		/* border_color */
		$this->add_control(
			'contact_border1_color',
			[
				'label' => esc_html__( 'Border Color', 'mediquet' ),
				'type' =>  \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'contact_border' => ['solid','double','dotted','dashed','default'],
				],								
			]
		);
		
	// contact Background Color
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'span_background_color',
        'label' => esc_html__('Background Color', 'textdomain'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area',
      ]
    );
	
	

	
	/* border_radius */
		$this->add_control(
			'contact_radius',
			[
				'label' => esc_html__( 'Border Radius', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
		
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'box_shadow',
			'label' => esc_html__( 'Box Shadow', 'mediquet' ),
			'selector' => '{{WRAPPER}} .contact_form_area',
		]
	); 
	 // contact Padding
    $this->add_responsive_control(
      'main_span_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // contact Margin
    $this->add_responsive_control(
      'main_span_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .categorie_form_area, {{WRAPPER}} .contact_form_area' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	
	$this->end_controls_section();



	// Fields
	
    $this->start_controls_section(
      'fields_style',
      [
        'label' => 'Contact Fields',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
     // Fields Text Color
     $this->add_control(
      'fields_text_color',
      [
        'label' => esc_html__('Text Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .contact-box input:not(input[type="submit"]), .contact-box textarea, {{WRAPPER}}  .contact_form_area select' => 'color: {{VALUE}}',
        ],
      ]
    );
    // Fields Placeholder Color
    $this->add_control(
      'fields_placeholder_color',
      [
        'label' => esc_html__('Placeholder Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .contact-box input:not(input[type="submit"])::placeholder, .contact-box textarea::placeholder' => 'color: {{VALUE}}',
        ],
      ]
    );

    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'filed_typography',
        'selector' => '{{WRAPPER}} .contact-box input:not(input[type="submit"])::placeholder, .contact-box textarea::placeholder, {{WRAPPER}}  .contact_form_area select',
      ]
    );
    // Fields Bg Color
    $this->add_control(
      'fields_bg',
      [
        'label' => esc_html__('Background Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .contact-box input:not(input[type="submit"]), .contact-box textarea' => 'background-color: {{VALUE}}',
        ],
      ]
    );
    
    // Fields Padding
    $this->add_responsive_control(
      'fields_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Padding', 'mediquet'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .contact-box input:not(input[type="submit"]), {{WRAPPER}} .contact-box textarea, {{WRAPPER}} .contact_form_area select' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );
    // Fields Margin
    $this->add_responsive_control(
      'fields_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'mediquet'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .contact-box input, .contact-box textarea' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );
  	// Fields Border Style 
		$this->add_control(
			'filed_border',
			[
				'label' => esc_html__( 'contact Border Style', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'none', 'mediquet' ),
					'solid' => esc_html__( 'Solid', 'mediquet' ),
					'double' => esc_html__( 'Double', 'mediquet' ),
					'dotted' => esc_html__( 'Dotted', 'mediquet' ),
					'dashed' => esc_html__( 'Dashed', 'mediquet' ),
					'default' => esc_html__( 'Default', 'mediquet' ),
				],
				'default' => 'default',
				'selectors' => [
					'{{WRAPPER}} .contact-box input, .contact-box textarea, {{WRAPPER}} .contact_form_area select' => 'border-style: {{VALUE}}',
				],
			]
		);		
		// Fields border 
		$this->add_control(
			'filed_style',
			[
				'label' => esc_html__( 'Width', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'selectors' => [
					'{{WRAPPER}} .contact-box input, .contact-box textarea, {{WRAPPER}} .contact_form_area select' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'filed_border' => ['solid','double','dotted','dashed'],
				],								
			]
		);
		/* border_color */
		$this->add_control(
			'filed_border1_color',
			[
				'label' => esc_html__( 'Border Color', 'mediquet' ),
				'type' =>  \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .contact-box input, .contact-box textarea, {{WRAPPER}} .contact_form_area select' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'filed_border' => ['solid','double','dotted','dashed','default'],
				],								
			]
		);
  	/* border_radius */
		$this->add_control(
			'contact_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .contact-box input, .contact-box textarea, {{WRAPPER}} .contact_form_area select' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],							
			]
		);
    // contact Width
    $this->add_responsive_control(
      'fields_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'mediquet'),
        'size_units' => ['px', 'em', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'devices' => ['desktop', 'tablet', 'mobile'],
        'selectors' => [
          '{{WRAPPER}} .contact_form_area input, {{WRAPPER}} .contact_form_area textarea, {{WRAPPER}} .contact_form_area select' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	
	// contact Height
    $this->add_responsive_control(
      'contect_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .contact_form_area input, {{WRAPPER}} .contact_form_area select' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
    // contact Height
    $this->add_responsive_control(
      'textarea_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Textarea Height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .contact_form_area textarea' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );

    $this->end_controls_section();

    /*===========  Start Controls Button section ============*/
    $this->start_controls_section(
      'contact_button_tab',
      [
        'label' => 'Contact Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
      ]
    );
    $this->start_controls_tabs(
      'contact_btn_tabs'
    );
      $this->start_controls_tab(
        'contact_btn_style_tab',
        [
          'label' => esc_html__('Normal', 'mediquet'),
        ]
      );
    // Contact Button Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .contact-box input[type="submit"]',
      ]
    );
    // Contact Button Color
    $this->add_control(
      'contact_button_color',
      [
        'label' => esc_html__('Text Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .contact-box input[type="submit"]' => 'color: {{VALUE}}',
        ],
      ]
    );
    // Contact Button Bg Color
    $this->add_control(
      'button_bg',
      [
        'label' => esc_html__('Background Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .contact-box input[type="submit"]' => 'background-color: {{VALUE}}',
        ],
      ]
    );

    // Fields Border Style 
		$this->add_control(
			'contact_button_border',
			[
				'label' => esc_html__( 'contact Border Style', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'none', 'mediquet' ),
					'solid' => esc_html__( 'Solid', 'mediquet' ),
					'double' => esc_html__( 'Double', 'mediquet' ),
					'dotted' => esc_html__( 'Dotted', 'mediquet' ),
					'dashed' => esc_html__( 'Dashed', 'mediquet' ),
					'default' => esc_html__( 'Default', 'mediquet' ),
				],
				'default' => 'default',
				'selectors' => [
					'{{WRAPPER}} .contact-box input[type="submit"], {{WRAPPER}} input.wpcf7-form-control.wpcf7-submit.has-spinner.wt_btn2' => 'border-style: {{VALUE}}',
				],
			]
		);		
		// Fields border 
		$this->add_control(
			'button_border_style',
			[
				'label' => esc_html__( 'Width', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'selectors' => [
					'{{WRAPPER}} .contact-box input[type="submit"], {{WRAPPER}} input.wpcf7-form-control.wpcf7-submit.has-spinner.wt_btn2' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'contact_button_border' => ['solid','double','dotted','dashed'],
				],								
			]
		);
		/* border_color */
		$this->add_control(
			'contact_button_border_color',
			[
				'label' => esc_html__( 'Border Color', 'mediquet' ),
				'type' =>  \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} .contact-box input[type="submit"], {{WRAPPER}} input.wpcf7-form-control.wpcf7-submit.has-spinner.wt_btn2' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'contact_button_border' => ['solid','double','dotted','dashed','default'],
				],								
			]
		);

  	/* border_radius */
		$this->add_control(
			'contact_btn_border_radius',
			[
				'label' => esc_html__( 'Border Radius', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],
				'selectors' => [
					'{{WRAPPER}} .contact-box input[type="submit"], {{WRAPPER}} input.wpcf7-form-control.wpcf7-submit.has-spinner.wt_btn2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],							
			]
		);
  	// Contact Button width
    $this->add_responsive_control(
      'button_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('width', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .wtx_contact_btn input, .mc4wp-form-fields input, {{WRAPPER}} input.wpcf7-form-control.wpcf7-submit.has-spinner.wt_btn2' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
    // Contact Button Padding
    $this->add_responsive_control(
      'button_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Padding', 'mediquet'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .contact-box input[type="submit"], {{WRAPPER}} input.wpcf7-form-control.wpcf7-submit.has-spinner.wt_btn2' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );
   // Contact Button Padding
   $this->add_responsive_control(
    'button_margin',
    [
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'label' => esc_html__('margin', 'mediquet'),
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .contact_form_area .wt_btn2' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
    ]
  );
$this->end_controls_tab();
	
// Hover Tab
$this->start_controls_tab(
  'contact_btn_hover_tab',
  [
    'label' => esc_html__('Hover', 'mediquet'),
  ]
);
// Contact Button Hover Background
$this->add_control(
  'button_bg_hover',
  [
    'label' => esc_html__('Background Hover Color', 'mediquet'),
    'type' => \Elementor\Controls_Manager::COLOR,
    'selectors' => [
      '{{WRAPPER}} .wtx_contact_btn:hover input' => 'background-color: {{VALUE}}',
    ],
  ]
);

// Text Color
$this->add_control(
  'contact_button_color_hover',
  [
    'label' => esc_html__('Text Hover Color', 'mediquet'),
    'type' => \Elementor\Controls_Manager::COLOR,
    'selectors' => [
      '{{WRAPPER}} .wtx_contact_btn:hover input' => 'color: {{VALUE}}',
    ],
  ]
);
$this->end_controls_tab();

$this->end_controls_tabs();

	
  }

  protected function render() {
    $settings = $this->get_settings_for_display();
  

    echo do_shortcode('[contact-form-7 id="' . $settings['contact_form_list'] . '" html_class="contact-box" ]');
  }
}

// Get Contact Form 7 all Forms

    function mediquet_get_wpcf7_list() {
      $options = array();
     
      if (function_exists('wpcf7')) {
        $wpcf7_form_list = get_posts(array(
          'post_type' => 'wpcf7_contact_form',
          'showposts' => 999,
        ));
        $options[0] = esc_html__('Select a Contact Form', '');
        
        if (!empty($wpcf7_form_list) && !is_wp_error($wpcf7_form_list)) {
          foreach ($wpcf7_form_list as $post) {
            $options[$post->ID] = $post->post_title;
          }
        } else {
          $options[0] = esc_html__('Create a Form First', '');
        
        }
      }
      
      return $options;
    }

