<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Images Widget
 */

class Image_Widget extends \Elementor\Widget_Base


{
  public function get_name()
  {
    return 'morat-image';
  }

  public function get_title()
  {
    return esc_html__('mediquet Image', 'mediquet-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }


  protected function register_controls()
  {
    /**
     * Image Control Section
     */
	
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

	// image Style
	$this->add_control(
	'image_style',
	[
		'label' => esc_html__('image Style', 'mediquet'),
		'type' => \Elementor\Controls_Manager::SELECT,
		'default' => '1',
		'options' => [
		'1'  => esc_html__('image style 01', 'mediquet'),
		'2' => esc_html__('image animation border', 'mediquet'),
		],
	]
	);
	// image alignment
	 $this->add_responsive_control(
		'img_aligg',
		[
			'label' => esc_html__( 'Alignment', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => [
				'left' => [
					'title' => esc_html__( 'Left', 'mediquet' ),
					'icon' => 'eicon-text-align-left',
				],
				'center' => [
					'title' => esc_html__( 'Center', 'mediquet' ),
					'icon' => 'eicon-text-align-center',
				],
				'right' => [
					'title' => esc_html__( 'Right', 'mediquet' ),
					'icon' => 'eicon-text-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'mediquet' ),
					'icon' => 'eicon-text-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .t1_about_thumb img, {{WRAPPER}} .t1_about_thumb' => 'text-align: {{VALUE}};',
			],
		]
	);
	
    // Url
    $this->add_control(
      'image',
      [
        'label' => 'Choose Image',
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => plugin_dir_url(__DIR__) . 'assets/images/placeholder.png',
        ]
      ]
    );

    $this->end_controls_section();

    /**
     * Image Style
     */
    $this->start_controls_section(
      'images_style',
      [
        'label' => 'Image',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Width
    $this->add_responsive_control(
		'image_width',
		[
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__( 'Width', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				]
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
			'selectors' => [
				'{{WRAPPER}} .emediquet_image' => 'width: {{SIZE}}{{UNIT}};',
			],
		]
	);
    // Height
    $this->add_responsive_control(
		'image_height',
		[
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__( 'Height', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				]
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
			'selectors' => [
				'{{WRAPPER}} .emediquet_image' => 'height: {{SIZE}}{{UNIT}};',
			],
		]
	);
	$this->add_responsive_control(
		'space',
		[
			'label' => esc_html__( 'Max Width', 'elementor' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'default' => [
				'unit' => '%',
			],
			'tablet_default' => [
				'unit' => '%',
			],
			'mobile_default' => [
				'unit' => '%',
			],
			'size_units' => [ '%', 'px', 'vw' ],
			'range' => [
				'%' => [
					'min' => 1,
					'max' => 100,
				],
				'px' => [
					'min' => 1,
					'max' => 1000,
				],
				'vw' => [
					'min' => 1,
					'max' => 100,
				],
			],
			'selectors' => [
				'{{WRAPPER}} .emediquet_image' => 'max-width: {{SIZE}}{{UNIT}};',
			],
		]
	);
	// images postion
	$this->add_responsive_control(
		'img_position',
		[
			'label' => esc_html__( 'Position', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'default' => '',
			'options' => [
				'' => esc_html__( 'Default', 'mediquet' ),
				'absolute' => esc_html__( 'Absolute', 'mediquet' ),
				'fixed' => esc_html__( 'Fixed', 'mediquet' ),
				'inherit' => esc_html__( 'inherit', 'mediquet' ),
			],
			'selectors' => [
						'{{WRAPPER}} .t1_about_thumb img' => 'position: {{VALUE}};',
					],
		]
	);
	/* images top */
	$this->add_responsive_control(
		'witr_icon_top',
		[
			'label' => esc_html__( 'Icon Top', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],		
			],
			'condition' => [
				'img_position' => ["absolute","fixed"],
			],						
			'selectors' => [
				'{{WRAPPER}} .t1_about_thumb img' => 'top: {{SIZE}}{{UNIT}};',
			],
		]
	);
				
	/*images left */
	$this->add_responsive_control(
		'witr_icon_left',
		[
			'label' => esc_html__( 'Icon Left', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SLIDER,
			'size_units' => [ 'px', '%' ],
			'range' => [
				'px' => [
					'min' => -100,
					'max' => 500,
				],
				'%' => [
					'min' => -100,
					'max' => 100,
				],	
			],
			'condition' => [
				'img_position' => ["absolute","fixed"],
			],						
			'selectors' => [
				'{{WRAPPER}} .t1_about_thumb img' => 'left: {{SIZE}}{{UNIT}};',
			],
		]
	);	
	
	//images margin
	 $this->add_responsive_control(
      'img_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .t1_about_thumb ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
		
    $this->end_controls_section();

	//images_border_style
	$this->start_controls_section(
		'images_border_style',
		[
		  'label' => 'Border Animation',
		  'tab' => \Elementor\Controls_Manager::TAB_STYLE
		]
	  );

	// Image border Background  
	$this->add_group_control(
	\Elementor\Group_Control_Background::get_type(),
	[
		'name' => 'image_border_background',
		'label' => esc_html__('Background', 'mediquet'),
		'types' => ['classic', 'gradient'],
		'selector' => '{{WRAPPER}} .t1_about_thumb.animation-border:before,{{WRAPPER}} .t1_about_thumb.animation-border:after ',
	]
	); 
	 //Image border Width
	 $this->add_responsive_control(
		'image_border_width',
		[
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__( 'After Width', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				]
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
			'selectors' => [
				'{{WRAPPER}} .t1_about_thumb.animation-border:after' => 'width: {{SIZE}}{{UNIT}};',
			],
		]
	);
    //Image border Height
    $this->add_responsive_control(
		'image_border_height',
		[
			'type' => \Elementor\Controls_Manager::SLIDER,
			'label' => esc_html__( 'Before Height', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'range' => [
				'px' => [
					'min' => 0,
					'max' => 1000,
				]
			],
			'devices' => [ 'desktop', 'tablet', 'mobile' ],
			'selectors' => [
				'{{WRAPPER}} .t1_about_thumb.animation-border:before' => 'height: {{SIZE}}{{UNIT}};',
			],
		]
	);


	  $this->end_controls_section();

  }

  protected function render()
  {
    $settings = $this->get_settings_for_display();

?>
 	<?php if ($settings['image_style'] === '1') : ?>
      <div class="t1_about_thumb">
       	 <img class="emediquet_image" src="<?= esc_url($settings['image']['url']) ?>" alt="">
      </div>

	  <?php elseif ($settings['image_style'] === '2') : ?>
		<div class="t1_about_thumb animation-border">
       	 <img class="emediquet_image" src="<?= esc_url($settings['image']['url']) ?>" alt="">
      </div>
	  <?php endif ?>
<?php
  }
}
