<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Team Widget
 */

class team_widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'morat-team2';
  }

  public function get_title() {
    return esc_html__('mediquet 02 Team', 'mediquet-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
	  
    // Content Section
	$this->start_controls_section(
      'content_section',
      [
        'label' => esc_html__('Team 02 Content', 'mediquet'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Team Style
    $this->add_control(
      'team_style',
      [
        'label' => esc_html__('Team Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('Team style 01', 'textdomain'),
          '2' => esc_html__('Team style 02', 'textdomain'),
          '3' => esc_html__('Team style 03', 'textdomain'),
        ],
      ]
    );
	
    $this->add_responsive_control(
			'team_align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .all_title_team' => 'text-align: {{VALUE}};',
				],
			]
		);
	// Image
    $this->add_control(
      'team_image',
      [
        'label' => esc_html__('Choose Image', 'mediquet'),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => plugin_dir_url(__DIR__) . 'assets/images/service-1.jpg',
        ],
      ]
    );
	
	 // Title
    $this->add_control(
      'list_title',
      [
        'label' => esc_html__('Title', 'mediquet'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => esc_html__('Team Title', 'mediquet'),
        'label_block' => true,
      ]
    );
	  // Url
    $this->add_control(
      'the_team_title',
      [
        'label' => esc_html__(' Link', 'mediquet'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '#',
        ],
        'label_block' => true,
      ]
    );
	
	
	//Sub Title
    $this->add_control(
      'sub_title',
      [
        'label' => esc_html__('Sub Title', 'mediquet'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => esc_html__('Team Title', 'mediquet'),
        'label_block' => true,
      ]
    );
    // Icon
    $this->add_control(
      'team_single_icons',
      [
        'label' => esc_html__('Icon', 'mediquet'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'default' => [
          'value' => 'fas fa-phone',
          'library' => 'fa-solid',
        ],
        'recommended' => [
          'fa-solid' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
          'fa-regular' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
        ],
		'condition' => [
				'team_style' => '2',
			],
      ]
    );
    //Sub Title
    $this->add_control(
      'contact_title',
      [
        'label' => esc_html__('contact Title', 'mediquet'),
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => esc_html__('+12 (88) 555-222', 'mediquet'),
        'label_block' => true,
        'condition' => [
          'team_style' => '2',
        ],
      ]
    );
    $repeater = new \Elementor\Repeater();
    // Icon
    $repeater->add_control(
      'teams_icon',
      [
        'label' => esc_html__( 'Icon', 'elementor' ),
        'type' =>  \Elementor\Controls_Manager::ICONS,
        'default' => [
          'value' => 'icofont-facebook',
          'library' => 'fa-solid',
        ],
        'fa4compatibility' => 'icon',
      ]
    );
	 // Url
   $repeater->add_control(
    'team_social_icon',
    [
      'label' => esc_html__(' Link', 'wazon'),
      'type' => \Elementor\Controls_Manager::URL,
      'placeholder' => esc_html__('https://your-link.com', 'wazon'),
      'options' => ['url'],
      'default' => [
        'url' => '#',
      ],
      'label_block' => true,
    ]
  );

	// Show Image
  $this->add_control(
    'show_icon_item',
    [
      'label' => esc_html__( 'Show List Item', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SWITCHER,
      'label_on' => esc_html__( 'Show', 'your-plugin' ),
      'label_off' => esc_html__( 'Hide', 'your-plugin' ),
      'return_value' => 'yes',
      'default' => 'no',
    ]
  );
 

  $this->add_control(
    'icon_list',
    [
      'label' => esc_html__( 'Icons Items', 'elementor' ),
      'type' =>  \Elementor\Controls_Manager::REPEATER,
      'fields' => $repeater->get_controls(),
      'default' => [
        [
          'text' => esc_html__( 'Icons Items #1', 'elementor' ),
          'team_social_icon' => [
            'value' => 'icofont-facebook',
            'library' => 'fa-solid',
          ],
        ],
        [
          'text' => esc_html__( 'Icons Items #2', 'elementor' ),
          'team_social_icon' => [
            'value' => 'icofont-google-plus',
            'library' => 'fa-solid',
          ],
        ],
        [
          'text' => esc_html__( 'Icons Items #3', 'elementor' ),
          'team_social_icon' => [
            'value' => 'icofont-google-plus',
            'library' => 'fa-solid',
          ],
        ],
      ],
      'condition' => [
        'show_icon_item' => 'yes',
      ],
      'title_field' => '{{{ elementor.helpers.renderIcon( this, team_social_icon, {}, "i", "panel" ) || \'<i class="{{ icon }}" aria-hidden="true"></i>\' }}} {{{ text }}}',
    ]
  );


 $this->end_controls_section();
	
	


	
	// Box Style
	 $this->start_controls_section(
      'box_style',
      [
        'label' => 'Box Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'boxs_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .all_title_team',
      ]
    );
	  // Box Padding 
    $this->add_responsive_control(
      'ser_box_padding',
      [
        'label' => 'Box Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .all_title_team' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );

    // Box Margin
    $this->add_responsive_control(
      'ser_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .all_title_team' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );
	 
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'box_shadow',
			'label' => esc_html__( 'Box Shadow', 'mediquet' ),
			'selector' => '{{WRAPPER}} .all_title_team',
		]
	); 
	 	/* border_radius */
	$this->add_control(
		'team__box_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .all_title_team' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	$this->end_controls_section();
	
	
	// Text Box Style
	 $this->start_controls_section(
      'text_box_style',
      [
        'label' => ' Content Box Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'text_boxs_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .wtx_team_content',
      ]
    );
	  // Box Padding 
    $this->add_responsive_control(
      'ter_box_padding',
      [
        'label' => 'text Box Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .wtx_team_content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    // Box Margin
    $this->add_responsive_control(
      'text_box_margin',
      [
        'label' => 'text_Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .wtx_team_content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );
	 	 	/* border_radius */
	$this->add_control(
		'team__content_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .team_style2 .wtx_team_content' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'text_box_shadow',
			'label' => esc_html__( 'Box Shadow', 'mediquet' ),
			'selector' => '{{WRAPPER}} .wtx_team_content',
		]
	); 
	 
	$this->end_controls_section();
	
	
    /* Title Style */
    $this->start_controls_section(
      'title_style',
      [
        'label' => 'Main Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Main Title Color
    $this->add_control(
      'team_title_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team_main_title a' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'title_typography',
        'selector' => '{{WRAPPER}} .team_main_title a',
      ]
    );

    // Main Title Padding
    $this->add_responsive_control(
      'title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_main_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );

    // Main Title Margin
    $this->add_responsive_control(
      'team_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_main_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );

    $this->end_controls_section();


    /* Sub Title Style */

    $this->start_controls_section(
      'sub_title_style',
      [
        'label' => 'Sub Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Sub Title Color
    $this->add_control(
      'sub_title_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team_sub_title' => 'color: {{VALUE}} !important',
        ],
      ]
    );

    // Sub Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'sub_title_typography',
        'selector' => '{{WRAPPER}} .team_sub_title',
      ]
    );

    // Sub Title Padding
    $this->add_responsive_control(
      'sub_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_sub_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );

    // Sub Title Margin
    $this->add_responsive_control(
      'sub_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_sub_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        
      ]
    );

    $this->end_controls_section();
	
	
   /**
     * Icon Style
     */

	 
	$this->start_controls_section(
      'icon_style',
      [
        'label' => 'Icon Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
    
    // Icon Color
    $this->add_control(
      'icon_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .team_icon i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .team_icons_items ul li a svg' => 'fill: {{VALUE}};',
        ]
      ]
    );

	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'icon_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a',
      ]
    );
	
    // Icon Size
    $this->add_responsive_control(
      'icon_size',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Size', 'mediquet'),
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'devices' => ['desktop', 'tablet', 'mobile'],
        'selectors' => [
          '{{WRAPPER}} .team_icon i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .team_icons_items ul li a svg' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// Team Icon Width
    $this->add_responsive_control(
      'team_icons_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// Team Icon height
    $this->add_responsive_control(
      'team_icons_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );	
	// Team Line height
    $this->add_responsive_control(
      'ser_icons_line_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('line-height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'line-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	/* witr_border_style */
	$this->add_control(
		'team_icons_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				'{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'tean_icon_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				'{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'team_icons_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'service_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'team_icons_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'icons_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	 // icons Padding
    $this->add_responsive_control(
      'icons_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // icons Margin
    $this->add_responsive_control(
      'icons_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .team_icon i, {{WRAPPER}} .team_icons_items ul li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	
	
/* hedding  */
	$this->add_control(
		'witr_hove',
		[
			'label' => esc_html__( ' Hover Color option', 'bitor' ),
			'type' =>\Elementor\Controls_Manager::HEADING,
		]
	);
    
    // icon1 Color
    $this->add_control(
      'icon1_hover_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .all_title_team:hover .team_icon i' => 'color: {{VALUE}}',
          '{{WRAPPER}} .team_icons_items ul li a:hover svg' => 'fill: {{VALUE}};',
        ]
      ]
    );

    // icon1 Background
    $this->add_control(
      'icon1_hover_bg',
      [
        'label' => 'Background',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .all_title_team:hover .team_icon i' => 'background-color: {{VALUE}}',
        ]
      ]
    );

   
	 $this->end_controls_section();

	
   /**
     * Image Style
     */

    $this->start_controls_section(
      'image_style',
      [
        'label' => 'Image Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	//  Width
    $this->add_responsive_control(
      'img_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .wtx_image_area img' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
    // Image Overlay
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'image_overlay_background',
        'label' => esc_html__('Overlay Background', 'textdomain'),
        'types' => ['classic', 'gradient', 'video'],
        'selector' => '{{WRAPPER}} .wtx_image_area:before',
      ]
    );
	


    $this->end_controls_section();	
	
	
  }


  protected function render() {
    $settings = $this->get_settings_for_display();
?>

    <?php
    if (!empty($settings['the_team_title']['url'])) {
      $this->add_link_attributes('the_team_title', $settings['the_team_title']);
    }
    elseif (!empty($settings['team_social_icon']['url'])) {
      $this->add_link_attributes('team_social_icon', $settings['team_social_icon']);
    }
	
    ?>
     
            <?php if ($settings['team_style'] == '1') : ?>
              <!--========  team_t1_01 ======== -->
                <div class=" all_title_team ">
                  <div class="wtx_image_area">
					           <img src="<?= esc_url($settings['team_image']['url']) ?>" alt="">
                  </div>
                  <div class="wtx_team_content">
                    <div class="wtx_content2 content1_bg_color">
                      <h5 class="team_main_title"><a <?php echo $this->get_render_attribute_string('the_team_title'); ?>><?= $settings['list_title'] ?></a></h5>
                      <span class="team_sub_title"><?= $settings['sub_title'] ?></span>
                    </div>
                    <?php if('yes' === $settings['show_icon_item']): ?>
                    <div class="team_icon">
                      <ul <?php $this->print_render_attribute_string( 'iconsss_list' ); ?>> 
                          <?php foreach ($settings['icon_list'] as $slide) : ?>
                            <li>
                            <a href= "<?php echo $slide['team_social_icon'] ['url']; ?>">
                              <?php \Elementor\Icons_Manager::render_icon($slide['teams_icon'], ['aria-hidden' => 'true',]); ?>
                            </a>
                            </li>
                            <?php endforeach ?>
                        </ul>
                    </div>
                    <?php endif ?>
                  </div>
                </div>   
                <?php elseif ($settings['team_style'] === '2') : ?>
                    <!--========  team_t1_02 ======== -->
                    <div class=" all_title_team team_style_2">
                    <div class="team_content_section">
                      <h5 class="team_main_title"><a <?php echo $this->get_render_attribute_string('the_team_title'); ?>><?= $settings['list_title'] ?></a></h5>
                      <span class="team_sub_title"><?= $settings['sub_title'] ?></span>
                    </div>
                    <div class="wtx_image_area">
                      <img src="<?= esc_url($settings['team_image']['url']) ?>" alt="">
                    </div>
                    <div class="team_contents">
                    <div class="wtx_team_content_inner">
                    <div class="team_contact_icon">
                    <?php \Elementor\Icons_Manager::render_icon($settings['team_single_icons'], ['aria-hidden' => 'true', 'class' => 'team_single_icons']); ?>
                      </div>
                    <h4 class="team_contact_title"><?= $settings['contact_title'] ?></h4>
                    </div>
                   </div>
                </div> 
		            	<?php elseif ($settings['team_style'] === '3') : ?>
                    <!--========  team_t1_02 ======== -->
                <div class=" all_title_team team_style2 team_st3">
                  <div class="wtx_image_area">
                  <img src="<?= esc_url($settings['team_image']['url']) ?>" alt="">
                  </div>
                  <div class="wtx_team_content">
                    <div class="wtx_content2 content1_bg_color">
                    <h5 class="team_main_title"><a <?php echo $this->get_render_attribute_string('the_team_title'); ?>><?= $settings['list_title'] ?></a></h5>
                        <span class="team_sub_title"><?= $settings['sub_title'] ?></span>
                        <div class="team_icons_items">
                          <ul <?php $this->print_render_attribute_string( 'iconsss_list' ); ?>> 
                          <?php foreach ($settings['icon_list'] as $slide) : ?>
                            <li>
                            <a href= "<?php echo $slide['team_social_icon'] ['url']; ?>">
                              <?php \Elementor\Icons_Manager::render_icon($slide['teams_icon'], ['aria-hidden' => 'true', ]); ?>
                            </a>
                            </li>
                            <?php endforeach ?>
                          </ul>
                    </div>
                   </div>
                  </div>
                 
                </div>

            <?php endif ?>

<?php
  }
}
