<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Counter Widget
 */

class Video_Widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'morat-video';
  }

  public function get_title()
  {
    return esc_html__('mediquet Video', 'mediquet-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls()
  {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
	    // video Style
    $this->add_control(
      'video_style',
      [
        'label' => esc_html__('video Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('video style 01', 'textdomain'),
          '2' => esc_html__('video style 02', 'textdomain'),
        ],
      ]
    );
	
	$this->add_responsive_control(
			'icon_position',
			[
				'label' => esc_html__( 'Position', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'Default', 'mediquet' ),
					'absolute' => esc_html__( 'Absolute', 'mediquet' ),
					'fixed' => esc_html__( 'Fixed', 'mediquet' ),
					'inherit' => esc_html__( 'inherit', 'mediquet' ),
				],
				'selectors' => [
							'{{WRAPPER}} .video_inner' => 'position: {{VALUE}};',
						],
			]
		);
		
		/* witr_icon_top */
				$this->add_responsive_control(
					'witr_icon_top',
					[
						'label' => esc_html__( 'Icon Top', 'mediquet' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => -100,
								'max' => 500,
							],
							'%' => [
								'min' => -100,
								'max' => 100,
							],		
						],
						'condition' => [
							'icon_position' => ["absolute","fixed"],
						],						
						'selectors' => [
							'{{WRAPPER}} .video_inner' => 'top: {{SIZE}}{{UNIT}};',
						],
					]
				);
				
				/* witr_icon_left */
				$this->add_responsive_control(
					'witr_icon_left',
					[
						'label' => esc_html__( 'Icon Left', 'mediquet' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => -100,
								'max' => 500,
							],
							'%' => [
								'min' => -100,
								'max' => 100,
							],	
						],
						'condition' => [
							'icon_position' => ["absolute","fixed"],
						],						
						'selectors' => [
							'{{WRAPPER}} .video_inner' => 'left: {{SIZE}}{{UNIT}};',
						],
					]
				);	
	

    // Url
    $this->add_control(
			'video_link',
			[
				'label' => esc_html__( 'Video Link', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => esc_html__( 'https://your-link.com', 'mediquet' ),
				'options' => [ 'url' ],
				'default' => [
					'url' => '',
				],
				'label_block' => true,
			]
		);

    $this->end_controls_section();

   

 /**
     * Video Style
     */
    $this->start_controls_section(
      'box_style',
      [
        'label' => 'Box Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

	
	// Box Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'box_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .video_inner.video_style2 ',
      ]
    ); 
		
	
    // Width
    $this->add_responsive_control(
			'video_width',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Width', 'mediquet' ),
        'szie_units' => ['px', 'em', '%'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .video_inner.video_style2' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

    // Height
    $this->add_responsive_control(
			'video_height',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Height', 'mediquet' ),
        'szie_units' => ['px', 'em', '%'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .video_inner.video_style2' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		// Line height
    $this->add_responsive_control(
      'video_line_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('line-height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
           '{{WRAPPER}} .video_inner.video_style2 ' => 'line-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
		
		
	 /* witr_border_style */
	$this->add_control(
		'video_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .video_inner.video_style2' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'box_video_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .video_inner.video_style2' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'video_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'vid_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .video_inner.video_style2' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'video_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'vide_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .video_inner.video_style2' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);	

	/*  Rotate */
		$this->add_responsive_control(
			'video_rotate',
			[
				'label' => esc_html__( 'Rotate', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'deg' ],
				'default' => [
					'size' => '',
					'unit' => 'deg',
				],
				'tablet_default' => [
					'unit' => 'deg',
				],
				'mobile_default' => [
					'unit' => 'deg',
				],
				'selectors' => [
					'{{WRAPPER}} .video_inner' => 'transform: rotate({{SIZE}}{{UNIT}});',
				],
			]
		);	
	
	
	
	
    $this->end_controls_section();







   /**
     * Video Style
     */
    $this->start_controls_section(
      'icon_style',
      [
        'label' => 'Box Icon Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'icon_typography',
        'selector' => '{{WRAPPER}} .video_inner i',
      ]
    );

    // Width
    $this->add_responsive_control(
			'icon_width',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Width', 'mediquet' ),
        'szie_units' => ['px', 'em', '%'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .video_inner a' => 'width: {{SIZE}}{{UNIT}};',
				],
			]
		);

    // Height
    $this->add_responsive_control(
			'icon_height',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Height', 'mediquet' ),
        'szie_units' => ['px', 'em', '%'],
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 400,
					],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} .video_inner a' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
		);

		/* border_radius */
	$this->add_control(
		'video_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .video_inner a, {{WRAPPER}} .video_inner a::before' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
		
    // Icon Color
    $this->add_control(
			'icon_color',
			[
				'label' => esc_html__( 'Icon Color', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video_inner i' => 'color: {{VALUE}}',
				],
			]
		);

    // Icon Background Color
    $this->add_control(
			'icon_bg',
			[
				'label' => esc_html__( 'Icon Background', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .video_inner a, .video_inner a::before' => 'background-color: {{VALUE}}',
				],
			]
		);

    $this->end_controls_section();
  }

  protected function render()
  {
    $settings = $this->get_settings_for_display();

    if ( ! empty( $settings['video_link']['url'] ) ) {
			$this->add_link_attributes( 'video_link', $settings['video_link'] );
		}

?>
 <?php if ($settings['video_style'] === '1') : ?>
    <div class="video_inner">
      <a class=" videobox" data-vbtype="youtube" data-autoplay="true" <?php echo $this->get_render_attribute_string( 'video_link' ); ?>>
        <i class="video_icon fas fa-play"></i></a>
    </div>
	<?php elseif ($settings['video_style'] === '2') : ?>
	<div class="video_inner video_style2">
      <a class=" videobox" data-vbtype="youtube" data-autoplay="true" <?php echo $this->get_render_attribute_string( 'video_link' ); ?>>
        <i class="video_icon fas fa-play"></i></a>
    </div>

	
	
	<?php endif ?>
	
<?php
  }
}
