<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Button Widget
 */


class app_button_widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'app-button';
  }

  public function get_title()
  {
    return esc_html__('app Button', 'app_button_widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }


  protected function register_controls()
  {
    /**
     * Button Control Section
     */
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
	
	// Button Style
    $this->add_control(
      'button_style',
      [
        'label' => esc_html__('Button Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('Button style 01', 'textdomain'),
          '2' => esc_html__('Button style 02', 'textdomain'),
        ],
      ]
    );
	
	
	
	
	
	
	
	
	$this->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .tbd_ab_btn' => 'text-align: {{VALUE}};',
				],
			]
		);
	
	$this->add_control(
      'btn_txt',
      [
        'label' => ' Button Text',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'placeholder' => 'MType button text ',
        'default' => 'Read More'
      ]
    );

    // Url
    $this->add_control(
      'button_link',
      [
        'label' => esc_html__('Link', 'mediquet'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '#',
        ],
        'label_block' => true,
      ]
    );

	
	
	$this->add_control(
      'app_txt',
      [
        'label' => ' Button Text 02',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'placeholder' => 'MType button text ',
        'default' => 'Read More'
      ]
    );

    // Url
    $this->add_control(
      'app_link',
      [
        'label' => esc_html__('Link', 'mediquet'),
        'type' => \Elementor\Controls_Manager::URL,
        'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
        'options' => ['url', 'is_external', 'nofollow'],
        'default' => [
          'url' => '#',
        ],
        'label_block' => true,
      ]
    );
	
	
	
	
	
    $this->end_controls_section();

    /**
     * Button Style Section
     */
    $this->start_controls_section(
      'app_button_color_style',
      [
        'label' => 'Button Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->start_controls_tabs(
      'app_button_style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'app_button_tab',
      [
        'label' => esc_html__('Normal', 'mediquet'),
      ]
    );

	// Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );
	
    // Color
    $this->add_control(
      'app_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );

	
	/* witr_border_style */
		$this->add_control(
			'arrow_border',
			[
				'label' => esc_html__( 'Border Style', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'options' => [
					'none' => esc_html__( 'none', 'mediquet' ),
					'solid' => esc_html__( 'Solid', 'mediquet' ),
					'double' => esc_html__( 'Double', 'mediquet' ),
					'dotted' => esc_html__( 'Dotted', 'mediquet' ),
					'dashed' => esc_html__( 'Dashed', 'mediquet' ),
					'default' => esc_html__( 'Default', 'mediquet' ),
				],
				'default' => 'none',
				'selectors' => [
					'{{WRAPPER}} a.tabtn' => 'border-style: {{VALUE}}',
				],
			]
		);		
		/* witr border */
		
		$this->add_control(
			'arrow_btn_style',
			[
				'label' => esc_html__( 'Width', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::DIMENSIONS,
				'selectors' => [
					'{{WRAPPER}} a.tabtn' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
				'condition' => [
					'arrow_border' => ['solid','double','dotted','dashed'],
				],								
			]
		);
		/* border_color */
		$this->add_control(
			'witr_border1_btn_color',
			[
				'label' => esc_html__( 'Border Color', 'mediquet' ),
				'type' =>  \Elementor\Controls_Manager::COLOR,
				
				'selectors' => [
					'{{WRAPPER}} a.tabtn' => 'border-color: {{VALUE}}',
				],
				'condition' => [
					'arrow_border' => ['solid','double','dotted','dashed','default'],
				],								
			]
		);

	
	/* border_radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'style_hover_tab',
      [
        'label' => esc_html__('Hover', 'mediquet'),
      ]
    );

    // Color
    $this->add_control(
      'app_hover_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn:hover' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'hover_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tabtn:hover',
      ]
    );
	
	/* border_color */
	$this->add_control(
		'before2_color',
		[
			'label' => esc_html__( 'Border Hover Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} a.tabtn:hover' => 'border-color: {{VALUE}}',
			],								
		]
	);
	

    $this->end_controls_tab();

    $this->end_controls_tabs();


    // Padding
    $this->add_responsive_control(
      'button_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__( 'Padding', 'mediquet' ),
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

// Box Margin
    $this->add_responsive_control(
      'ser_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .tbd_ab_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	 
	
	
	
    $this->end_controls_section();
  }


  protected function render()
  {
    $settings = $this->get_settings_for_display();
    if (!empty($settings['button_link']['url'])) {
      $this->add_link_attributes('button_link', $settings['button_link']);
    }
?>

	<?php if ($settings['button_style'] === '1') : ?>
    <div class="tbd_ab_btn app_btn">
	  <a <?php echo $this->get_render_attribute_string('button_link'); ?> class="tabtn"> <i=""aria-hidden="true" class="fab fa-google-play"><?= $settings['btn_txt'] ?></a>
	  
	  <a <?php echo $this->get_render_attribute_string('app_link'); ?> class="tabtn"> <i="" aria-hidden="true" class="fas fa-apple-alt"><?= $settings['app_txt'] ?></a>
	  
    </div>
	<?php elseif ($settings['button_style'] === '2') : ?>
	<div class="tbd_ab_btn app_btn">
	  <a <?php echo $this->get_render_attribute_string('button_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
	  
	  <a <?php echo $this->get_render_attribute_string('app_link'); ?> class="tabtn"><?= $settings['app_txt'] ?></a>
	  
    </div>
	
	
	<?php endif ?>

<?php
  }
}
