<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Counter Widget
 */

class Counter_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'counter-widget';
  }

  public function get_title() {
    return esc_html__('mediquet Counter', 'mediquet-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Content Section
	
	
	
	
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );
	
		
	  // Widget Style
    $this->add_control(
      'widget_style',
      [
        'label' => 'Widget Style',
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1' => 'counter style 01',
          '2' => 'counter style 02',
          '3' => 'counter style 03',
          '4' => 'counter style 04',
          '5' => 'counter style 05',
        ]
      ]
    );

	
	$this->add_responsive_control(
			'align',
			[
				'label' => esc_html__( 'Alignment', 'elementor' ),
				'type' => \Elementor\Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'elementor' ),
						'icon' => 'eicon-text-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'elementor' ),
						'icon' => 'eicon-text-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'elementor' ),
						'icon' => 'eicon-text-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'elementor' ),
						'icon' => 'eicon-text-align-justify',
					],
				],
				'selectors' => [
					'{{WRAPPER}} .txt_counters, {{WRAPPER}} .txt_counter' => 'text-align: {{VALUE}};',
				],
			]
		);
	
    /** Title */
    $this->add_control(
      'counter_title',
      [
        'label' => 'Title',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => 'Happy Clients'
      ]
    );

    /** Count */
    $this->add_control(
      'counter_count',
      [
        'label' => 'Count',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'default' => 45
      ]
    );
    /** Symbol */
    $this->add_control(
      'counter_symbol',
      [
        'label' => 'counter symble',
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => '+'
      ]
    );
    /** Description */
    $this->add_control(
      'counter_desc',
      [
        'label' => 'Description',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => 'We more stoic this along goodness this to ed wow manatee wastefuls and web editors now use non'
      ]
    );

	// Show Icon
    $this->add_control(
			'show_icon',
			[
				'label' => esc_html__( 'Show Icon', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);
	
	// Icon
    $this->add_control(
      'counter_icon',
      [
        'label' => esc_html__('Icon', 'mediquet'),
        'type' => \Elementor\Controls_Manager::ICONS,
        'default' => [
          'value' => 'fas fa-circle',
          'library' => 'fa-solid',
        ],
        'recommended' => [
          'fa-solid' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
          'fa-regular' => [
            'circle',
            'dot-circle',
            'square-full',
          ],
		  
        ],
		'condition' => [
				'show_icon' => 'yes',
			],
      ]
    );

	// Show Image
    $this->add_control(
			'show_img',
			[
				'label' => esc_html__( 'Show Image', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'no',
			]
		);
	
    // Image
    $this->add_control(
      'counter_icon_image',
      [
        'label' => esc_html__('Choose Image', 'mediquet'),
        'type' => \Elementor\Controls_Manager::MEDIA,
        'default' => [
          'url' => plugin_dir_url(__DIR__) . 'assets/images/placeholder.png',
        ],
		'condition' => [
				'show_img' => 'yes',
			],
      ]
    );
	
	
    $this->end_controls_section();


    /**
     * Counter Styles
     */

    $this->start_controls_section(
      'counter_style',
      [
        'label' => 'Counter Box Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    /** Background Image */
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'box_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_counter ,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn',
      ]
    ); 
	
	 /* witr_border_style */
	$this->add_control(
		'box_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .txt_counter,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'box_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .txt_counter,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'boxs_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_counter,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'counter_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .txt_counter,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	 // Box Margin
    $this->add_responsive_control(
      'counter_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_counter,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
    /** Padding */
    $this->add_responsive_control(
      'widget_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Padding', 'mediquet'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_counter,{{WRAPPER}} .counter_titles, {{WRAPPER}} .txt_counter_02 .txt_new_inn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );
	
	 $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'counter_hover_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_counter_02:hover .txt_new_inn,{{WRAPPER}} .counter_titles:hover, {{WRAPPER}} .txt_counter:hover:before',
      ]
    ); 
	
	/** Count Color */
    $this->add_control(
      'count_all_color_hover',
      [
        'label' => esc_html__('All_Color_Hover', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .txt_counter_02:hover .txt_new_inn h3, {{WRAPPER}} .txt_counter_02:hover .txt_new_inn span, {{WRAPPER}} .txt_counter_02:hover .txt_new_inn i, {{WRAPPER}} .txt_counter_02:hover .txt_counter_inn p , {{WRAPPER}} .txt_counter_02:hover .text_counter h4' => 'color: {{VALUE}}',
        ],
      ]
    );
	

    $this->end_controls_section();



     /* Count Style */
     $this->start_controls_section(
      'count_style',
      [
        'label' => 'Count Number',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Count Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'count_typography',
        'selector' => '{{WRAPPER}} .counter_title h3, {{WRAPPER}} .txt_new_inn h3, {{WRAPPER}} .txt_new_inn span',
      ]
    );
    /** Count Color */
    $this->add_control(
      'count_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .counter_title h3, {{WRAPPER}} .txt_new_inn h3' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Count margin
    $this->add_responsive_control(
      'count_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .counter_title h3, {{WRAPPER}} .txt_new_inn h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    /** Symbol Color */
    $this->add_control(
      'count_Symbol_color',
      [
        'label' => esc_html__('Symbol Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          ' {{WRAPPER}} .text_counter span , {{WRAPPER}} .txt_new_inn span ' => 'color: {{VALUE}}',
        ],
      ]
    );

    $this->end_controls_section();


    
    /* Title Style */
    $this->start_controls_section(
      'tilte_style',
      [
        'label' => 'Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    /** Title Color */
    $this->add_control(
      'counter_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .counter_title h4, {{WRAPPER}} .txt_counter_02 h4, {{WRAPPER}} .counter_titles h4' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'counter_title_typography',
        'selector' => '{{WRAPPER}} .counter_title h4, {{WRAPPER}} .txt_counter_02 h4, {{WRAPPER}} .counter_titles h4',
      ]
    );
    
    // Title margin
    $this->add_responsive_control(
      'counter_title_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .counter_title h4, {{WRAPPER}} .txt_counter_02 h4, {{WRAPPER}} .counter_titles h4' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    $this->end_controls_section();


    
    /* Description Style */
    $this->start_controls_section(
      'desc_style',
      [
        'label' => 'Description',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );


    /** Desc Color */
    $this->add_control(
      'desc_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .counter_desc' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Title margin
    $this->add_responsive_control(
      'desc_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .counter_desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'desc_typography',
        'selector' => '{{WRAPPER}} .counter_desc',
      ]
    );
	 $this->end_controls_section();
	
	 /* Icon Style */
    $this->start_controls_section(
      'icon_style',
      [
        'label' => 'Icon Style',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
    // Icon Color
    $this->add_control(
      'counter_icon_color',
      [
        'label' => 'Color',
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .counter_titles i' => 'color: {{VALUE}};',
          '{{WRAPPER}} .counter_titles svg' => 'fill: {{VALUE}};',
        ]
      ]
    );

	// Icon Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'counter_icon_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section',
      ]
    );
     // Icon Size
     $this->add_responsive_control(
      'counter_icon_size',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Size', 'mediquet'),
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 200,
          ],
        ],
        'devices' => ['desktop', 'tablet', 'mobile'],
        'selectors' => [
          '{{WRAPPER}} .counter_titles i' => 'font-size: {{SIZE}}{{UNIT}};',
          '{{WRAPPER}} .counter_titles svg, {{WRAPPER}} .counter_icon_section svg' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
  // Icon center
  $this->add_responsive_control(
      'counter_icon_align',
      [
        'label' => esc_html__( 'Alignment', 'elementor' ),
        'type' => \Elementor\Controls_Manager::CHOOSE,
        'options' => [
          'left' => [
            'title' => esc_html__( 'Left', 'elementor' ),
            'icon' => 'eicon-text-align-left',
          ],
          'center' => [
            'title' => esc_html__( 'Center', 'elementor' ),
            'icon' => 'eicon-text-align-center',
          ],
          'right' => [
            'title' => esc_html__( 'Right', 'elementor' ),
            'icon' => 'eicon-text-align-right',
          ],
          'justify' => [
            'title' => esc_html__( 'Justified', 'elementor' ),
            'icon' => 'eicon-text-align-justify',
          ],
        ],
        'selectors' => [
          '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section' => 'text-align: {{VALUE}};',
        ],
      ]
    );
    // icon Width
    $this->add_responsive_control(
      'counter_icons_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section,
          {{WRAPPER}} .counter_titles img' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
  // icon height
  $this->add_responsive_control(
    'counter_icons_height',
    [
      'type' => \Elementor\Controls_Manager::SLIDER,
      'label' => esc_html__('height', 'mediquet'),
      'size_units' => ['px', '%'],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 500,
        ],
        '%' => [
          'min' => 0,
          'max' => 100
        ]
      ],
      'selectors' => [
         '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section,{{WRAPPER}} .counter_titles img' => 'height: {{SIZE}}{{UNIT}};',
      ],
    ]
  );	
  // Line height
  $this->add_responsive_control(
    'counter_icons_line_height',
    [
      'type' => \Elementor\Controls_Manager::SLIDER,
      'label' => esc_html__('line-height', 'mediquet'),
      'size_units' => ['px', '%'],
      'range' => [
        'px' => [
          'min' => 0,
          'max' => 500,
        ],
        '%' => [
          'min' => 0,
          'max' => 100
        ]
      ],
      'selectors' => [
         '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section' => 'line-height: {{SIZE}}{{UNIT}};',
      ],
    ]
  );
  /* witr_border_style */
  $this->add_control(
    'counter_icons_border',
    [
      'label' => esc_html__( 'Border Style', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::SELECT,
      'options' => [
        'none' => esc_html__( 'none', 'mediquet' ),
        'solid' => esc_html__( 'Solid', 'mediquet' ),
        'double' => esc_html__( 'Double', 'mediquet' ),
        'dotted' => esc_html__( 'Dotted', 'mediquet' ),
        'dashed' => esc_html__( 'Dashed', 'mediquet' ),
        'default' => esc_html__( 'Default', 'mediquet' ),
      ],
      'default' => 'none',
      'selectors' => [
        '{{WRAPPER}} .counter_titles i,  {{WRAPPER}} .counter_icon_section,{{WRAPPER}} counter_titles img' => 'border-style: {{VALUE}}',
      ],
    ]
  );		
  /* witr border */
  $this->add_control(
    'counter_icon_bods_style',
    [
      'label' => esc_html__( 'Width', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'selectors' => [
        '{{WRAPPER}} .counter_titles i,  {{WRAPPER}} .counter_icon_section,{{WRAPPER}} counter_titles img' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
      'condition' => [
        'counter_icons_border' => ['solid','double','dotted','dashed'],
      ],								
    ]
  );
  /* border_color */
  $this->add_control(
    'counter_border1_color',
    [
      'label' => esc_html__( 'Border Color', 'mediquet' ),
      'type' =>  \Elementor\Controls_Manager::COLOR,
      
      'selectors' => [
        '{{WRAPPER}} .counter_titles i,  {{WRAPPER}} .counter_icon_section,{{WRAPPER}} counter_titles img' => 'border-color: {{VALUE}}',
      ],
      'condition' => [
        'counter_icons_border' => ['solid','double','dotted','dashed','default'],
      ],								
    ]
  );
  /* border_radius */
  $this->add_control(
    'counter_icons_radius',
    [
      'label' => esc_html__( 'Border Radius', 'mediquet' ),
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'size_units' => [ 'px', '%' ],
      'selectors' => [
        '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section,{{WRAPPER}} counter_titles img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],							
    ]
  );
  // icons Padding
    $this->add_responsive_control(
      'counter_icons_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section,{{WRAPPER}} counter_titles img' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // icons Margin
    $this->add_responsive_control(
      'counter_icons_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .counter_titles i, {{WRAPPER}} .counter_icon_section,{{WRAPPER}} counter_titles img' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	

    $this->end_controls_section();



  }

  protected function render() {
    $settings = $this->get_settings_for_display();
	
   if ($settings['widget_style'] == '1') : 
?>

    <div class="txt_counter" >
      <div class="txt_counter_inn">
        <div class="counter_title txt_new_inn">
          <h3 class="counter"><?= $settings['counter_count'] ?></h3>
          <span><?= $settings['counter_symbol'] ?></span>
          <h4><?= $settings['counter_title'] ?></h4>
        </div>
        <p class="counter_desc"><?= $settings['counter_desc'] ?></p>
      </div>
      </div>
	   <?php elseif ($settings['widget_style'] === '2') : ?>
      <div class="txt_counters counter_style2" >
            <div class="txt_counter_02">
            <div class="counter_titles txt_new_inn">
            <?php if('yes' === $settings['show_icon']): ?>
            <div class="counter_icon_section">
             <?php \Elementor\Icons_Manager::render_icon($settings['counter_icon'], ['aria-hidden' => 'true', 'class' => 'counter_icon']); ?>
            </div>
            <?php endif ?>
        <?php if('yes' === $settings['show_img']): ?>
          <img src="<?= esc_url($settings['counter_icon_image']['url']) ?>" alt="">
          <?php endif ?>
          <div class="text_counter">
            <div class="counter_symbol">
                <h3 class="counter"><?= $settings['counter_count'] ?></h3>
                <span><?= $settings['counter_symbol'] ?></span>
              </div>
            <h4><?= $settings['counter_title'] ?></h4>
          </div>
          </div>
            
          </div>
        </div>
        <?php elseif ($settings['widget_style'] === '3') : ?>
        <div class="txt_counters" >
              <div class="counter_titles txt_new_inn counter_03">
          <?php if('yes' === $settings['show_icon']): ?>
          <?php \Elementor\Icons_Manager::render_icon($settings['counter_icon'], ['aria-hidden' => 'true', 'class' => 'counter_icon']); ?>
          <?php if('yes' === $settings['show_img']): ?>
            <img src="<?= esc_url($settings['counter_icon_image']['url']) ?>" alt="">
            <?php endif ?>
          <?php endif ?>
                <h3 class="counter"><?= $settings['counter_count'] ?></h3>
                <span><?= $settings['counter_symbol'] ?></span>
            <h4><?= $settings['counter_title'] ?></h4>
            </div>
          </div>
          <?php elseif ($settings['widget_style'] === '4') : ?>
            <div class="txt_counters" >
             <div class="txt_counter_02">
                <div class="counter_titles txt_new_inn">
                  <?php \Elementor\Icons_Manager::render_icon($settings['counter_icon'], ['aria-hidden' => 'true', 'class' => 'counter_icon']); ?>
                  <?php if('yes' === $settings['show_img']): ?>
                    <img src="<?= esc_url($settings['counter_icon_image']['url']) ?>" alt="">
                    <?php endif ?>
                    <div class="text_counter">
                    <h4><?= $settings['counter_title'] ?></h4>
                      <div class="counter_symbol">
                          <h3 class="counter"><?= $settings['counter_count'] ?></h3>
                          <span><?= $settings['counter_symbol'] ?></span>
                        </div>
                    </div>
                </div>
               </div>
              </div>
              <?php elseif ($settings['widget_style'] === '5') : ?>
               <div class="txt_counters" >
                  <div class="txt_counter_02">
                  <div class="counter_titles txt_new_inn">
                  <?php if('yes' === $settings['show_icon']): ?>
                  <div class="counter_icon_section">
                  <?php \Elementor\Icons_Manager::render_icon($settings['counter_icon'], ['aria-hidden' => 'true', 'class' => 'counter_icon']); ?>
                  </div>
                  <?php endif ?>
                  <?php if('yes' === $settings['show_img']): ?>
                    <img src="<?= esc_url($settings['counter_icon_image']['url']) ?>" alt="">
                    <?php endif ?>
                    <div class="text_counter">
                      <div class="counter_symbol">
                          <h3 class="counter"><?= $settings['counter_count'] ?></h3>
                          <span><?= $settings['counter_symbol'] ?></span>
                        </div>
                      <h4><?= $settings['counter_title'] ?></h4>
                    </div>
                    </div>
                </div>
              </div>     

	
	<?php endif ?>
	
    <?php if (is_admin()) :
      if (!defined('ELEMENTOR_VERSION'))
        return;
    ?>
	
	 <?php endif ?>
	
     

   
   
   

<?php
  }
}
