<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Counter Widget
 */

class Portfolio_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'morat-portfolio';
  }

  public function get_title() {
    return esc_html__('mediquet Portfolio', 'mediquet-widget');
  }

  public function get_categories() {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls() {
    // Tab Controls
    $this->start_controls_section(
      'tab_controls',
      [
        'label' => 'Tab Controls',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Project Style
    $this->add_control(
      'project_style',
      [
        'label' => esc_html__('Project Style', 'textdomain'),
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1'  => esc_html__('Project Style 01', 'textdomain'),
          '2' => esc_html__('Project Style 02', 'textdomain'),
          '3' => esc_html__('Project Style 03', 'textdomain'),
          '4' => esc_html__('Project Style 04', 'textdomain'),
        ],
      ]
    );

	$this->add_responsive_control(
		'txt_item_filter',
		[
			'label' => esc_html__( 'tab Alignment', 'elementor' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => [
				'left' => [
					'title' => esc_html__( 'Left', 'elementor' ),
					'icon' => 'eicon-text-align-left',
				],
				'center' => [
					'title' => esc_html__( 'Center', 'elementor' ),
					'icon' => 'eicon-text-align-center',
				],
				'right' => [
					'title' => esc_html__( 'Right', 'elementor' ),
					'icon' => 'eicon-text-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'elementor' ),
					'icon' => 'eicon-text-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .txt_item_filter' => 'text-align: {{VALUE}};',
			],
		]
	);
	
    // Tab count
    $this->add_control(
      'tab_count',
      [
        'label' => 'Number of Tabs',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    );
	
	/* column_style*/
    $this->add_control(
        'witr_column_grid',
        [
            'label' => esc_html__( 'Columns style', 'mediquet' ),
            'type' => \Elementor\Controls_Manager::SELECT,					
            'default' => '3',
            'options' => [
                '12' => esc_html__( '1', 'mediquet' ),
                '6' => esc_html__( '2', 'mediquet' ),
                '4' => esc_html__( '3', 'mediquet' ),
                '3' => esc_html__( '4', 'mediquet' ),
                '2' => esc_html__( '6', 'mediquet' ),
            ],
        ]
    );
			
		// Show show_menu_bar
		$this->add_control(
			'show_menu_bar',
			[
				'label' => esc_html__( 'Show Categori', 'textdomain' ),
				'type' => \Elementor\Controls_Manager::SWITCHER,
				'label_on' => esc_html__( 'Show', 'your-plugin' ),
				'label_off' => esc_html__( 'Hide', 'your-plugin' ),
				'return_value' => 'yes',
				'default' => 'yes',
			]
		);	
			
			
			
		 // Post count
    $this->add_control(
      'post_count',
      [
        'label' => 'Number of Post',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'max' => 12,
        'default' => 3
      ]
    );	
     // Blog Post adc
     $this->add_control(
      'adc_project',
      [
        'label' => esc_html__( 'Project ASC/DSC style', 'mediquet' ),
        'type' => \Elementor\Controls_Manager::SELECT,
                  'separator' => 'before',					
        'options' => [
          'DESC'	=> esc_html__( 'Descending', 'mediquet' ),
          'ASC'	=> esc_html__( 'Ascending', 'mediquet' )
        ],
        'default' => 'DESC',
      ]
    );

  // Button Text
  $this->add_control(
    'active_txt',
    [
      'label' => esc_html__('Active Text', 'mediquet'),
      'type' => \Elementor\Controls_Manager::TEXTAREA,
      'default' => esc_html__('All Design', 'mediquet'),
      'label_block' => true,
    ]
  );

    // Show Icon
    $this->add_control(
      'show_btn',
      [
        'label' => esc_html__( 'Show Button', 'mediquet' ),
        'type' => \Elementor\Controls_Manager::SWITCHER,
        'label_on' => esc_html__( 'Show', 'your-plugin' ),
        'label_off' => esc_html__( 'Hide', 'your-plugin' ),
        'return_value' => 'yes',
        'default' => 'no',
      ]
    );
  // Button Text
  $this->add_control(
    'btn_txt',
    [
      'label' => esc_html__('Button Text', 'mediquet'),
      'type' => \Elementor\Controls_Manager::TEXTAREA,
      'default' => esc_html__('Read More', 'mediquet'),
      'label_block' => true,
      'condition' => [
				'show_btn' => 'yes',
			],
    ]
  );
  //  Button Url 
  $this->add_control(
    'button_link',
    [
      'label' => esc_html__('Button Link', 'mediquet'),
      'type' => \Elementor\Controls_Manager::URL,
      'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
      'options' => ['url', 'is_external', 'nofollow'],
      'default' => [
        'url' => '#',
      ],
      'condition' => [
				'show_btn' => 'yes',
			],
      'label_block' => true,
    ],
  
  );


	
    $this->end_controls_section();





	/*=========== Blog posts  Button Style Section start ============*/
  $this->start_controls_section(
    'tab_style',
    [
      'label' => 'Tab Box Option',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );
  // posts Button tab
  $this->start_controls_tabs(
    'portfolio_menu_style_tabs'
  );
  // posts Button Normal Tab
  $this->start_controls_tab(
    'portfolio_normal_tab',
    [
      'label' => esc_html__('Normal', 'mediquet'),
    ]
  );
  //Tab Color 
  $this->add_control(
    'tab_color',
    [
      'label' => esc_html__('Tab Color', 'mediquet'),
      'type' => \Elementor\Controls_Manager::COLOR,
      'selectors' => [
        '{{WRAPPER}} .item_filter li' => 'color: {{VALUE}}',
      ],
    ]
  );

  $this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
      'name' => 'tab_bg_color',
      'label' => esc_html__('Menu Background', 'mediquet'),
      'types' => ['classic', 'gradient'],
      'selector' => '{{WRAPPER}} .item_filter li',
    ]
  ); 
  // Tab margin
  $this->add_responsive_control(
    'tab_margin',
    [
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'label' => esc_html__('Margin', 'textdomain'),
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .item_filter li' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
    ]
  );

  // Tab padding
  $this->add_responsive_control(
    'tab_padding',
    [
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'label' => esc_html__('Padding', 'textdomain'),
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .item_filter li' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
    ]
  );

  // Tab margin
  $this->add_responsive_control(
    'Box_tab_margin',
    [
      'type' => \Elementor\Controls_Manager::DIMENSIONS,
      'label' => esc_html__('Box Margin', 'textdomain'),
      'size_units' => ['px', 'em', '%'],
      'selectors' => [
        '{{WRAPPER}} .txt_item_filter' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
      ],
    ]
  );


  // Tab Typography
  $this->add_group_control(
    \Elementor\Group_Control_Typography::get_type(),
    [
      'name' => 'tab_typography',
      'selector' => '{{WRAPPER}} .item_filter li',
    ]
  );


  $this->end_controls_tab();

  // posts Button Hover Tab
  $this->start_controls_tab(
    'tab_style_hover',
    [
      'label' => esc_html__('Hover', 'mediquet'),
    ]
  );
   //Tab Color 
 $this->add_control(
  'tab_hover_color',
  [
    'label' => esc_html__('Hover Color', 'mediquet'),
    'type' => \Elementor\Controls_Manager::COLOR,
    'selectors' => [
      '{{WRAPPER}} .txt_item_filter ul li:hover' => 'color: {{VALUE}}',
    ],
  ]
);
    //Tab Active Bg Color 
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'hover_background',
        'label' => esc_html__('Active Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_item_filter ul li:hover',
      ]
    );
$this->end_controls_tab();

  // posts Button Hover Tab
  $this->start_controls_tab(
    'tab_style_active',
    [
      'label' => esc_html__('Active', 'mediquet'),
    ]
  );
    /** Title Color */
    $this->add_control(
      'active_color',
      [
        'label' => esc_html__('Active Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .sfilter-menu .active_item' => 'color: {{VALUE}}',
        ],
      ]
    );
    //Tab Active Bg Color 
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'active_background',
        'label' => esc_html__('Active Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .sfilter-menu .active_item',
      ]
    ); 


  $this->end_controls_tab();
  $this->end_controls_tabs();

	
	$this->end_controls_section();

 

    /** Title Style */
    $this->start_controls_section(
      'tilte_style',
      [
        'label' => 'Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    /** Title Color */
    $this->add_control(
      'portfolio_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .project_title a' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Title margin
    $this->add_responsive_control(
      'project_title_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__('Margin', 'textdomain'),
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .project_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

    // Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'portfolio_title_typography',
        'selector' => '{{WRAPPER}} .project_title a',
      ]
    );

    $this->end_controls_section();
	
	
	
	  /** Title Style */

    $this->start_controls_section(
      'images_style',
      [
        'label' => 'Images',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
	    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_img:before',
      ]
    );
  

    $this->end_controls_section();
	
	
	 /** Content Style */
    $this->start_controls_section(
      'content_style',
      [
        'label' => 'Content Box',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
	
	    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'content_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04',
      ]
    );
  
  

    // Box Padding 
    $this->add_responsive_control(
      'content_box_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Box Margin
    $this->add_responsive_control(
      'content_box_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	 
	/* box shadow */	
	$this->add_group_control(
		\Elementor\Group_Control_Box_Shadow::get_type(),
		[
			'name' => 'witr_box_shadowsbox',
			'label' => esc_html__( 'Box Shadow', 'mediquet' ),
			'selector' => '{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04',
		]
	); 
	 
	 /* witr_border_style */
	$this->add_control(
		'box_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'Default',
			'selectors' => [
				 '{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'box_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'boxs_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'box_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'service_border_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .txt_content_port,  {{WRAPPER}} .txt_al_protfolio.style_04' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	 
    $this->end_controls_section();
	

	 /** Content Style */
   $this->start_controls_section(
    'arrow_button_style',
    [
      'label' => 'Arrow Button Box',
      'tab' => \Elementor\Controls_Manager::TAB_STYLE
    ]
  );

     /** Arrow Color */
      $this->add_control(
        'arrow_button_color',
        [
          'label' => esc_html__('Active Color', 'mediquet'),
          'type' => \Elementor\Controls_Manager::COLOR,
          'selectors' => [
            '{{WRAPPER}} .txt_ptitle a i' => 'color: {{VALUE}}',
          ],
        ]
      );
    // Background
  $this->add_group_control(
    \Elementor\Group_Control_Background::get_type(),
    [
      'name' => 'arrow_button_background',
      'label' => esc_html__('Background', 'mediquet'),
      'types' => ['classic', 'gradient'],
      'selector' => '{{WRAPPER}} .txt_ptitle a i',
    ]
  );

 /* witr_border_style */
$this->add_control(
  'arrow_button_border',
  [
    'label' => esc_html__( 'Border Style', 'mediquet' ),
    'type' => \Elementor\Controls_Manager::SELECT,
    'options' => [
      'none' => esc_html__( 'none', 'mediquet' ),
      'solid' => esc_html__( 'Solid', 'mediquet' ),
      'double' => esc_html__( 'Double', 'mediquet' ),
      'dotted' => esc_html__( 'Dotted', 'mediquet' ),
      'dashed' => esc_html__( 'Dashed', 'mediquet' ),
      'default' => esc_html__( 'Default', 'mediquet' ),
    ],
    'default' => 'Default',
    'selectors' => [
       '{{WRAPPER}} .txt_ptitle a i' => 'border-style: {{VALUE}}',
    ],
  ]
);		
/* witr border */

$this->add_control(
  'arrow_button_border_style',
  [
    'label' => esc_html__( 'Width', 'mediquet' ),
    'type' => \Elementor\Controls_Manager::DIMENSIONS,
    'selectors' => [
       '{{WRAPPER}} .txt_ptitle a i' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    ],
    'condition' => [
      'arrow_button_border' => ['solid','double','dotted','dashed'],
    ],								
  ]
);
/* border_color */
$this->add_control(
  'arrow_button_border1_color',
  [
    'label' => esc_html__( 'Border Color', 'mediquet' ),
    'type' =>  \Elementor\Controls_Manager::COLOR,
    
    'selectors' => [
      '{{WRAPPER}} .txt_ptitle a i' => 'border-color: {{VALUE}}',
    ],
    'condition' => [
      'arrow_button_border' => ['solid','double','dotted','dashed','default'],
    ],								
  ]
);
/* border_radius */
$this->add_control(
  'arrow_button_border_radius',
  [
    'label' => esc_html__( 'Border Radius', 'mediquet' ),
    'type' => \Elementor\Controls_Manager::DIMENSIONS,
    'size_units' => [ 'px', '%' ],
    'selectors' => [
      '{{WRAPPER}} .txt_ptitle a i' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    ],							
  ]
);
 
 // Box Padding 
 $this->add_responsive_control(
  'arrow_button_padding',
  [
    'label' => 'Padding',
    'type' => \Elementor\Controls_Manager::DIMENSIONS,
    'size_units' => ['px', 'em', '%'],
    'selectors' => [
      '{{WRAPPER}} .txt_ptitle a' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    ],
    'separator' => 'before',
  ]
);

// Box Margin
$this->add_responsive_control(
  'arrow_button_margin',
  [
    'label' => 'Margin',
    'type' => \Elementor\Controls_Manager::DIMENSIONS,
    'size_units' => ['px', 'em', '%'],
    'selectors' => [
      '{{WRAPPER}} .txt_ptitle a' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
    ],
    'separator' => 'before',
  ]
);

  $this->end_controls_section();



    /** Button Style */

    $this->start_controls_section(
      'button_style',
      [
        'label' => 'Button',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE,
        
      ]
    );

    $this->start_controls_tabs(
      'btn_style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'btn_style_normal_tab',
      [
        'label' => esc_html__('Normal', 'mediquet'),
      ]
    );
    // Color
    $this->add_control(
      'btn_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn,{{WRAPPER}} .tabtn i' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .tabtn, {{WRAPPER}} .tabtn i, {{WRAPPER}} .tb_service_sen a i',
      ]
    );
    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'btn_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient', 'video'],
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );
	
	
	 /* witr_border_style */
	$this->add_control(
		'btn_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .tabtn' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'btn_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .tabtn' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'btn_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'btn_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .tabtn' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'btn_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
    // Padding
    $this->add_responsive_control(
      'button_padding',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__( 'Padding', 'mediquet' ),
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );
	
	
	
			// button margin
	  $this->add_responsive_control(
		'button_margin',
		[
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'label' => esc_html__( 'Margin', 'mediquet' ),
			'size_units' => [ 'px', 'em', '%' ],
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
		]
	);
	
	
	
	// icon Width
    $this->add_responsive_control(
      'button_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	// icon height
    $this->add_responsive_control(
      'button_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
           '{{WRAPPER}} .tabtn' => 'height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );	
	// Line height
    $this->add_responsive_control(
      'button_line_height',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('line-height', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
           '{{WRAPPER}} .tabtn ' => 'line-height: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	
    $this->add_responsive_control(
			'btn_position',
			[
				'label' => esc_html__( 'Position', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SELECT,
				'default' => '',
				'options' => [
					'' => esc_html__( 'Default', 'mediquet' ),
					'absolute' => esc_html__( 'Absolute', 'mediquet' ),
					'fixed' => esc_html__( 'Fixed', 'mediquet' ),
					'inherit' => esc_html__( 'inherit', 'mediquet' ),
				],
				'selectors' => [
							'{{WRAPPER}} .tb_service_sen.ab_ser_ar a.tabtn' => 'position: {{VALUE}};',
						],
			]
		);
		
		/* witr_icon_top */
				$this->add_responsive_control(
					'witr_btn_top',
					[
						'label' => esc_html__( 'Button Top', 'mediquet' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => -100,
								'max' => 500,
							],
							'%' => [
								'min' => -100,
								'max' => 100,
							],		
						],
						'condition' => [
							'btn_position' => ["absolute","fixed"],
						],						
						'selectors' => [
							'{{WRAPPER}} .tb_service_sen.ab_ser_ar a.tabtn' => 'top: {{SIZE}}{{UNIT}};',
						],
					]
				);
				
				/* witr_icon_left */
				$this->add_responsive_control(
					'witr_btn_left',
					[
						'label' => esc_html__( 'Button Left', 'mediquet' ),
						'type' => \Elementor\Controls_Manager::SLIDER,
						'size_units' => [ 'px', '%' ],
						'range' => [
							'px' => [
								'min' => -100,
								'max' => 500,
							],
							'%' => [
								'min' => -100,
								'max' => 100,
							],	
						],
						'condition' => [
							'btn_position' => ["absolute","fixed"],
						],						
						'selectors' => [
							'{{WRAPPER}} .tb_service_sen.ab_ser_ar a.tabtn' => 'left: {{SIZE}}{{UNIT}};',
						],
					]
				);				
				/*  Rotate */
		$this->add_responsive_control(
			'button_rotate',
			[
				'label' => esc_html__( 'Rotate', 'mediquet' ),
				'type' => \Elementor\Controls_Manager::SLIDER,
				'size_units' => [ 'deg' ],
				'default' => [
					'size' => '',
					'unit' => 'deg',
				],
				'tablet_default' => [
					'unit' => 'deg',
				],
				'mobile_default' => [
					'unit' => 'deg',
				],
				'selectors' => [
					'{{WRAPPER}} .ab_ser_ar .tabtn' => 'transform: rotate({{SIZE}}{{UNIT}});',
				],
			]
		);	

    $this->end_controls_tab();
	

    // Hover Tab
    $this->start_controls_tab(
      'btn_style_hover_tab',
      [
        'label' => esc_html__('Hover', 'mediquet'),
      ]
    );

    // Color
    $this->add_control(
      'btn_hover_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn:hover, {{WRAPPER}} .tb_service_sen.service_08:hover .tabtn, {{WRAPPER}}.tb_service_sen.service_08:hover a.tabtn' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'btn_hover_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient', 'video'],
        'selector' => '{{WRAPPER}} .tabtn:hover, {{WRAPPER}} .tb_service_sen.service_08:hover .tabtn',
      ]
    );


    $this->end_controls_tab();

    $this->end_controls_tabs();

    $this->end_controls_section();

  }



  protected function render() {
    $settings = $this->get_settings_for_display();

    // Query Posts
    $args = array(
      'post_type' => 'project',
      'post_status' => 'publish',
	  'posts_per_page' => $settings['post_count'],
      'orderby' => 'title',
      'order' => 'ASC',
      'order' => $settings['adc_project'],
    );
	

    $loop = new WP_Query($args);

    $tab_slugs = get_categories(array(
      'taxonomy' => 'project_cat',
      'number' => $settings['tab_count'],
      'orderby' => 'name',
      'order'   => 'ASC'
    ));

?>
<div class="row">
   <div class="col-md-12">
      <?php if('yes' === $settings['show_menu_bar']): ?>
      <div class="txt_item_filter">
         <ul class="sfilter-menu item_filter ">
            <li class="active_item" data-filter="*"> <?= $settings['active_txt'] ?></li>
            <?php foreach ($tab_slugs as $tab) : ?>
            <li data-filter=".<?= $tab->slug ?>"><?= $tab->name ?></li>
            <?php endforeach ?>
         </ul>
      </div>
      <?php endif ?>
   </div>
</div>
<div class="row txt_portfolio project_filter <?= $settings['project_style'] == '1' ? 'txtstyle_1' : 'txtstyle_2 pr_top' ?> ">
   <?php while ($loop->have_posts()) : $loop->the_post();
      $project_cats = get_the_terms(get_the_ID(), 'project_cat');
      $class = '';
      
      if($project_cats){
        foreach ($project_cats as $cat) {
          $class .= $cat->slug;
          $class .= ' ';
        }
      }
      ?>
   <?php if ($settings['project_style'] == '1') : ?> 
   <!--======== projects style 01======== -->
   <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item  col-md-6 col-sm-12 <?= $class ?> txt_btm">
      <div class="txt_al_protfolio">
         <div class="txt_img">
            <img src="<?= the_post_thumbnail_url() ?>" alt="">
         </div>
         <div class="txt_icon">
            <a href=""><i class="icofont-ui-search"></i></a>
         </div>
         <div class="txt_content_port">
            <div class="txt_ptitle">
               <h3 class="project_title"><a href="#"><?= the_title() ?></a></h3>
               <p class="project_title"><?= the_title() ?></p>
            </div>
         </div>
      </div>
   </div>
   <!--======== projects style 02======== -->
   <?php elseif ($settings['project_style'] === '2') : ?>
   <div class="col-lg-<?= $settings['witr_column_grid'] ?> grid-item  col-md-6 col-sm-12 <?= $class ?> txt_btm">
      <div class="txt_al_protfolio">
         <div class="txt_img">
            <img src="<?= the_post_thumbnail_url() ?>" alt="">
         </div>
         <div class="tbd_pr_area">
            <div class="txt_content_port">
               <div class="txt_ptitle">
                  <div class="port_icon">
                     <i class="icofont-network-tower"></i>
                  </div>
                  <h3 class="project_title"><a href="<?= get_the_permalink() ?>"><?= the_title() ?></a></h3>
                  <p><?= the_excerpt() ?></p>
               </div>
            </div>
         </div>
      </div>
   </div>
   <!--======== projects style 03======== -->
   <?php elseif ($settings['project_style'] === '3') : ?>
   <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item  col-md-6 col-sm-12 <?= $class ?> txt_btm">
      <div class="txt_al_protfolio style_03">
         <div class="txt_img">
            <img src="<?= the_post_thumbnail_url() ?>" alt="">
            <div class="txt_content_port">
               <div class="txt_ptitle">
                  <h3 class="project_title"><a href="#"><?= the_title() ?></a></h3>
                  <p><?= get_the_content() ?></p>
               </div>
               <div class="right_icon">
                  <a href="#"><i class="icofont-arrow-up"></i></a>
               </div>
            </div>
         </div>
      </div>
   </div>
   <!--======== projects style 04======== -->
   <?php elseif ($settings['project_style'] === '4') : ?>
   <div class="col-lg-<?= $settings['witr_column_grid'] ?>  grid-item  col-md-6 col-sm-12 <?= $class ?> txt_btm">
      <div class="txt_al_protfolio style_04">
         <div class="txt_img">
            <img src="<?= the_post_thumbnail_url() ?>" alt="">
         </div>
         <div class="txt_ptitle">
           <div class="protfolio_conten">
              <h3 class="project_title"><a href="#"><?= the_title() ?></a></h3>
              <p class="project_content"><?= the_content() ?></p>
              
            </div>
            </div>
            <div class="button_area">
            <?php if('yes' === $settings['show_btn']): ?>
                    <a  class="tabtn" href= "<?php echo $settings['button_link'] ['url']; ?>" > <?= $settings['btn_txt'] ?></a>
                  <?php endif ?> 
                  </div>
          
      </div>
   </div>
		  
        <?php endif ?>
      <?php endwhile ?>

    </div>

   

<?php
  }
}
