<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Section Info Widget
 */

class Section_Info_Widget extends \Elementor\Widget_Base
{
  public function get_name()
  {
    return 'section-info';
  }

  public function get_title()
  {
    return esc_html__('Section Info', 'mediquet-widget');
  }

  public function get_categories()
  {
    return ['basic'];
  }

  /**
   * Controls
   */

  protected function register_controls()
  {
    // Content Section
    $this->start_controls_section(
      'content_section',
      [
        'label' => 'Content',
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    // Widget Style
    $this->add_control(
      'widget_style',
      [
        'label' => 'Widget Style',
        'type' => \Elementor\Controls_Manager::SELECT,
        'default' => '1',
        'options' => [
          '1' => 'Title style 01',
          '2' => 'Title style 02',
        ]
      ]
    );

	$this->add_responsive_control(
		'title_align',
		[
			'label' => esc_html__( 'Alignment', 'elementor' ),
			'type' => \Elementor\Controls_Manager::CHOOSE,
			'options' => [
				'left' => [
					'title' => esc_html__( 'Left', 'elementor' ),
					'icon' => 'eicon-text-align-left',
				],
				'center' => [
					'title' => esc_html__( 'Center', 'elementor' ),
					'icon' => 'eicon-text-align-center',
				],
				'right' => [
					'title' => esc_html__( 'Right', 'elementor' ),
					'icon' => 'eicon-text-align-right',
				],
				'justify' => [
					'title' => esc_html__( 'Justified', 'elementor' ),
					'icon' => 'eicon-text-align-justify',
				],
			],
			'selectors' => [
				'{{WRAPPER}} .t1_top_title' => 'text-align: {{VALUE}};',
			],
		]
	);
	
    // Main Title
    $this->add_control(
      'main_title',
      [
        'label' => 'Main Title',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'placeholder' => 'Main title here',
        'default' => 'title 01'
      ]
    );

    // Sub Title
    $this->add_control(
      'sub_title',
      [
        'label' => 'Sub Title',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'placeholder' => 'Sub title here',
        'default' => 'We Are Provide Rent of Best Service.'
      ]
    );

    // Description
    $this->add_control(
      'desc',
      [
        'label' => 'Description',
        'type' => \Elementor\Controls_Manager::TEXTAREA,
        'default' => "If you are going to use a passage of Lorem Ipsu, you need this be sure there isn't anything embarrassing hidden in the best middle of text. All the Lorem Ipsum generators ."
      ]
    );
  // Title
  $this->add_control(
    'btn_txt',
    [
      'label' => esc_html__('Button Text', 'mediquet'),
      'type' => \Elementor\Controls_Manager::TEXTAREA,
      'default' => esc_html__('Reade More', 'mediquet'),
      'label_block' => true,
    ]
  );
  // Url
  $this->add_control(
    'button_link',
    [
      'label' => esc_html__('Link', 'mediquet'),
      'type' => \Elementor\Controls_Manager::URL,
      'placeholder' => esc_html__('https://your-link.com', 'mediquet'),
      'options' => ['url', 'is_external', 'nofollow'],
      'default' => [
        'url' => '#',
      ],
      'label_block' => true,
    ]
  );



    $this->end_controls_section();

    
    /**
     * Top Title Style
     */

     $this->start_controls_section(
      'sub_title_style',
      [
        'label' => 'Top Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Top Title Color
    $this->add_control(
      'top_title_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_sub_title' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Top Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'top_title_typography',
        'selector' => '{{WRAPPER}} .section_sub_title',
      ]
    );

	//heading Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'heading_bg_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .t1_top_title h1',
      ]
    );
	//heading Background  
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'after_bg_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .t1_top_title h1:after',
      ]
    );
	
	/* witr_border_style */
	$this->add_control(
		'heading_border',
		[
			'label' => esc_html__( 'Border Style', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::SELECT,
			'options' => [
				'none' => esc_html__( 'none', 'mediquet' ),
				'solid' => esc_html__( 'Solid', 'mediquet' ),
				'double' => esc_html__( 'Double', 'mediquet' ),
				'dotted' => esc_html__( 'Dotted', 'mediquet' ),
				'dashed' => esc_html__( 'Dashed', 'mediquet' ),
				'default' => esc_html__( 'Default', 'mediquet' ),
			],
			'default' => 'none',
			'selectors' => [
				 '{{WRAPPER}} .t1_top_title h1' => 'border-style: {{VALUE}}',
			],
		]
	);		
	/* witr border */
	
	$this->add_control(
		'icon_bods_style',
		[
			'label' => esc_html__( 'Width', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'selectors' => [
				 '{{WRAPPER}} .t1_top_title h1' => 'border-width: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],
			'condition' => [
				'heading_border' => ['solid','double','dotted','dashed'],
			],								
		]
	);
	/* border_color */
	$this->add_control(
		'ser_border1_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} .t1_top_title h1' => 'border-color: {{VALUE}}',
			],
			'condition' => [
				'heading_border' => ['solid','double','dotted','dashed','default'],
			],								
		]
	);
	/* border_radius */
	$this->add_control(
		'icons_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} .t1_top_title h1' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
    // Sub Title Padding
    $this->add_responsive_control(
      'sub_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_sub_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Sub Title Margin
    $this->add_responsive_control(
      'sub_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_sub_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();

    /**
     * Main Title Style
     */

    $this->start_controls_section(
      'main_title_style',
      [
        'label' => 'Middle Title',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );
    // Main Title Color
    $this->add_control(
      'main_title_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_main_title' => 'color: {{VALUE}}',
        ],
      ]
    );
    // Title span Color
    $this->add_control(
      'title_span_color',
      [
        'label' => esc_html__('Span Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_main_title span' => 'color: {{VALUE}}',
        ],
      ]
    );
    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'main_title_typography',
        'selector' => '{{WRAPPER}} .section_main_title',
      ]
    );

    // Main Title Padding
    $this->add_responsive_control(
      'main_title_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_main_title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Main Title Margin
    $this->add_responsive_control(
      'main_title_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_main_title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();


    /**
     * Description Style
     */

    $this->start_controls_section(
      'desc_style',
      [
        'label' => 'Decription',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    // Des Color
    $this->add_control(
      'desc_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .section_desc' => 'color: {{VALUE}}',
        ],
      ]
    );
    // Content Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'desc_typography',
        'selector' => '{{WRAPPER}} .section_desc',
      ]
    );

	// content Width
    $this->add_responsive_control(
      'content_width',
      [
        'type' => \Elementor\Controls_Manager::SLIDER,
        'label' => esc_html__('Width', 'mediquet'),
        'size_units' => ['px', '%'],
        'range' => [
          'px' => [
            'min' => 0,
            'max' => 500,
          ],
          '%' => [
            'min' => 0,
            'max' => 100
          ]
        ],
        'selectors' => [
          '{{WRAPPER}} .t1_top_text p, {{WRAPPER}} .t1_top_title p' => 'width: {{SIZE}}{{UNIT}};',
        ],
      ]
    );
	 
    // Desc Padding
    $this->add_responsive_control(
      'desc_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_desc' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    // Desc Margin
    $this->add_responsive_control(
      'desc_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .section_desc' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );

    $this->end_controls_section();
	
	 /**
     * Button Style Section
     */
    $this->start_controls_section(
      'button_style',
      [
        'label' => 'Button Color Option',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

    $this->start_controls_tabs(
      'section_button_style_tabs'
    );

    // Normal Tab
    $this->start_controls_tab(
      'section_style_title_tab',
      [
        'label' => esc_html__('Normal', 'mediquet'),
      ]
    );

	// Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'button_typography',
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );
	
    // Color
    $this->add_control(
      'title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tabtn',
      ]
    );

	/* border_color */
	$this->add_control(
		'before_color',
		[
			'label' => esc_html__( 'Border Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} a.tabtn:after' => 'border-color: {{VALUE}}',
			],								
		]
	);
	
	/* border_radius */
	$this->add_control(
		'btn_radius',
		[
			'label' => esc_html__( 'Border Radius', 'mediquet' ),
			'type' => \Elementor\Controls_Manager::DIMENSIONS,
			'size_units' => [ 'px', '%' ],
			'selectors' => [
				'{{WRAPPER}} a.tabtn' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
			],							
		]
	);
	
	  // Main Title Padding
    $this->add_responsive_control(
      'btn_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} a.tabtn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	
	/* btn_margin */
	$this->add_responsive_control(
      'btn_margin',
      [
        'label' => 'Margin',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .title_btn' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
    $this->end_controls_tab();

    // Hover Tab
    $this->start_controls_tab(
      'style_hover_tab',
      [
        'label' => esc_html__('Hover', 'mediquet'),
      ]
    );

    // Color
    $this->add_control(
      'hover_title_color',
      [
        'label' => esc_html__('Title Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .tabtn:hover' => 'color: {{VALUE}}',
        ],
      ]
    );


    // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'hover_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .tabtn:hover',
      ]
    );
	
	/* border_color */
	$this->add_control(
		'before2_color',
		[
			'label' => esc_html__( 'Border Hover Color', 'mediquet' ),
			'type' =>  \Elementor\Controls_Manager::COLOR,
			
			'selectors' => [
				'{{WRAPPER}} a.tabtn:hover.tabtn:after' => 'border-color: {{VALUE}}',
			],								
		]
	);
	

    $this->end_controls_tab();

    $this->end_controls_tabs();
	
	
	
	
  }

  protected function render() {
    $settings = $this->get_settings_for_display();
?>

    <?php
    if (!empty($settings['button_link']['url'])) {
      $this->add_link_attributes('button_link', $settings['button_link']);
    }

    ?>
    <?php if ($settings['widget_style'] === '1') : ?>
      <div class="t1_top_title stly_one">
        <h1 class="section_sub_title"><?= $settings['main_title'] ?></h1>
        <h2 class="section_main_title"><?= $settings['sub_title'] ?></h2>
        <p class="section_desc"> <?= $settings['desc'] ?></p>
      </div>
    <?php elseif ($settings['widget_style'] === '2') : ?> 
	  <div class="row">
        <div class="col-lg-8 col-md-8 col-sm-12">
			<div class="t1_top_title">
			  <h1 class="section_sub_title"><?= $settings['main_title'] ?></h1>
			  <h2 class="section_main_title"><?= $settings['sub_title'] ?></h2>
			  <p class="section_desc">
			  <?= $settings['desc'] ?></p>
			</div>
		</div>
		<div class="col-lg-4 col-md-4 col-sm-12">
			<div class="tbd_ab_btn title_btn">
          <a <?php echo $this->get_render_attribute_string('button_link'); ?> class="tabtn"><?= $settings['btn_txt'] ?></a>
			</div>
			</div>
		</div>

    <?php endif ?>


    <?php
  }
}
