<?php
if (!defined('ABSPATH')) {
  exit; // Exit if accessed directly.
}

/**
 * Section Info Widget
 */

class Skill_Widget extends \Elementor\Widget_Base {
  public function get_name() {
    return 'morat-skill';
  }

  public function get_title() {
    return esc_html__('mediquet Skill', 'mediquet-widget');
  }

  public function get_categories() {
    return ['basic'];
  }



  /**
   * Control
   */

  protected function register_controls() {
    $this->start_controls_section(
      'content_section',
      [
        'label' => esc_html__('Content', 'mediquet'),
        'tab' => \Elementor\Controls_Manager::TAB_CONTENT,
      ]
    );

    $repeater = new \Elementor\Repeater();

    // Title
    $repeater->add_control(
      'list_title',
      [
        'label' => esc_html__('Title', 'mediquet'),
        'type' => \Elementor\Controls_Manager::TEXT,
        'default' => esc_html__('Skill Title', 'mediquet'),
        'label_block' => true,
      ]
    );

    // Skill Slider
    $repeater->add_control(
      'skill_count',
      [
        'label' => 'Skill Count',
        'type' => \Elementor\Controls_Manager::NUMBER,
        'min' => 0,
        'max' => 100,
        'default' => 50,
      ]
    );

    $this->add_control(
      'list',
      [
        'label' => esc_html__('Skill List', 'mediquet'),
        'type' => \Elementor\Controls_Manager::REPEATER,
        'fields' => $repeater->get_controls(),
        'default' => [
          [
            'list_title' => esc_html__('Skill #1', 'mediquet'),
          ],
          [
            'list_title' => esc_html__('Skill #2', 'mediquet'),
          ],
        ],
        'title_field' => '{{{ list_title }}}',
      ]
    );

    $this->end_controls_section();
	
	
	
	  /**
     * Main Title Style
     */

    $this->start_controls_section(
      'main_title_style',
      [
        'label' => 'Bar Background',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );

	 // Color
    $this->add_control(
      'bar_color',
      [
        'label' => esc_html__('Bar Color', 'textdomain'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} {{CURRENT_ITEM}} span.fill' => 'background: {{VALUE}} !important'
        ],
      ]
    );
	
	
	// Color
    $this->add_control(
      'bar1_color',
      [
        'label' => esc_html__('Bar background  Color', 'textdomain'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .barfiller' => 'background: {{VALUE}} !important'
        ],
      ]
    );

    // Bar height
    $this->add_control(
			'bar_height',
			[
				'type' => \Elementor\Controls_Manager::SLIDER,
				'label' => esc_html__( 'Bar Height', 'textdomain' ),
				'range' => [
					'px' => [
						'min' => 0,
						'max' => 100,
					],
				],
        'default' => [
					'size' => 5,
					'unit' => 'px',
				],
				'devices' => [ 'desktop', 'tablet', 'mobile' ],
				'selectors' => [
					'{{WRAPPER}} {{CURRENT_ITEM}} .barfiller' => 'height: {{SIZE}}{{UNIT}};',
				],
			]
			
			
		);
	$this->end_controls_section();

	
	// start
	$this->start_controls_section(
      'main_title2_style',
      [
        'label' => 'Tile color ',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );	
	

      // skill  Title Typography
      $this->add_group_control(
        \Elementor\Group_Control_Typography::get_type(),
        [
          'name' => 'skill_title_typography',
          'selector' => '{{WRAPPER}} .progress_item h3',
        ]
      );
      	// skill Title Color
    $this->add_control(
      'skill_title_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .progress_item h3' => 'color: {{VALUE}}',
        ],
      ]
    );
		// skill Title margin
	  $this->add_responsive_control(
      'skill_title_margin',
      [
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'label' => esc_html__( 'Margin', 'mediquet' ),
        'size_units' => [ 'px', 'em', '%' ],
        'selectors' => [
          '{{WRAPPER}} .progress_item h3' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
      ]
    );

	$this->end_controls_section();
		
		
	// start
	$this->start_controls_section(
      'value_style',
      [
        'label' => 'value color ',
        'tab' => \Elementor\Controls_Manager::TAB_STYLE
      ]
    );	
	
	// Main Title Color
    $this->add_control(
      'skill_title1_color',
      [
        'label' => esc_html__('Color', 'mediquet'),
        'type' => \Elementor\Controls_Manager::COLOR,
        'selectors' => [
          '{{WRAPPER}} .barfiller .tip' => 'color: {{VALUE}}',
        ],
      ]
    );

    // Main Title Typography
    $this->add_group_control(
      \Elementor\Group_Control_Typography::get_type(),
      [
        'name' => 'skill1_title_typography',
        'selector' => '{{WRAPPER}} .barfiller .tip',
      ]
    );

	 // Background
    $this->add_group_control(
      \Elementor\Group_Control_Background::get_type(),
      [
        'name' => 'skill1_background',
        'label' => esc_html__('Background', 'mediquet'),
        'types' => ['classic', 'gradient'],
        'selector' => '{{WRAPPER}} .barfiller .tip',
      ]
    );
	
	// Main Title Padding
    $this->add_responsive_control(
      'skill_padding',
      [
        'label' => 'Padding',
        'type' => \Elementor\Controls_Manager::DIMENSIONS,
        'size_units' => ['px', 'em', '%'],
        'selectors' => [
          '{{WRAPPER}} .barfiller .tip' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
        ],
        'separator' => 'before',
      ]
    );
	
	
	
	$this->end_controls_section();	
		
		
		
	
  }


  protected function render() {
    $settings = $this->get_settings_for_display();

?>

    <?php if (is_admin()) :

      if (!defined('ELEMENTOR_VERSION')) :
        return;
      endif
    ?>

      <script>
        // skill bar initialize
        $(document).ready(function() {
          $(".bar").each(function() {
            $(this).barfiller();
          });
        });
      </script>

    <?php endif ?>


      <?php foreach ($settings['list'] as $item) { ?>

        <div class="progress_item elementor-repeater-item-<?= esc_attr($item['_id'])?>">
          <h3> <?= $item['list_title'] ?></h3>
          <div class="bar barfiller">
            <span class="tip"></span>
            <span class="fill" data-percentage="<?= $item['skill_count'] ?>"></span>
          </div>
        </div>

      <?php } ?>


<?php
  }
}
